package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.Layout;
import com.hyjavacharts.model.highcharts.constants.VerticalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesAreaspline;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class AreaSpline extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart().type(ChartType.AREASPLINE);
		
		chartOptions.title().text("Average fruit consumption during one week");

		chartOptions.legend()
			.layout(Layout.VERTICAL)
			.align(HorizontalAlign.LEFT)
			.verticalAlign(VerticalAlign.TOP)
			.x(150)
			.y(100)
			.floating(true)
			.borderWidth(1)
			.backgroundColor(new Color().setColorValue("(Highcharts.theme && Highcharts.theme.legendBackgroundColor) || '#FFFFFF'"));
		
		chartOptions.xAxisSingle().categories(new ArrayList<String>(Arrays.asList("Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday", "Sunday")));
		chartOptions.xAxisSingle()
			.plotBandsSingle()
				.from(4.5)
				.to(6.5)
				.color(new Color("rgba(68, 170, 213, .2)"));
		
		chartOptions.yAxisSingle()
			.title().text("Fruit units");

		chartOptions.tooltip().shared(true).valueSuffix(" units");
		chartOptions.credits().enabled(false);
		chartOptions.plotOptions().areaspline().fillOpacity(0.5);
		
		SeriesAreaspline seriesAreaspline = new SeriesAreaspline();
		seriesAreaspline.name("John");
		seriesAreaspline.dataAsArrayNumber(getSeriesData(1));
		chartOptions.series().add(seriesAreaspline);
		
		seriesAreaspline = new SeriesAreaspline();
		seriesAreaspline.name("Jane");
		seriesAreaspline.dataAsArrayNumber(getSeriesData(2));
		chartOptions.series().add(seriesAreaspline);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Number> getSeriesData(int series) {
		ArrayList<Number> array = new ArrayList<Number>();
		
    	if (series == 1) {
    		array = new ArrayList<Number>(Arrays.asList(3, 4, 3, 5, 4, 10, 12));
    	}
    	else if (series == 2) {
    		array = new ArrayList<Number>(Arrays.asList(1, 3, 4, 3, 3, 5, 4));
    	}

    	return array;
    }
}
