package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.Stacking;
import com.hyjavacharts.model.highcharts.series.SeriesBar;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class BarWithNegativeStack extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart()
			.type(ChartType.BAR);
		chartOptions
			.title().text("Population pyramid for Germany, 2015");
		chartOptions
			.subtitle().text("Source: <a href=\"http://populationpyramid.net/germany/2015/\">Population Pyramids of the World from 1950 to 2100</a>");
		
		XAxis xAxi = new XAxis();
		xAxi.categories(new ArrayList<String>(Arrays.asList("0-4", "5-9", "10-14", "15-19",
				"20-24", "25-29", "30-34", "35-39", "40-44",
				"45-49", "50-54", "55-59", "60-64", "65-69",                  
				"70-74", "75-79", "80-84", "85-89", "90-94",
				"95-99", "100 + ")));
		xAxi.reversed(false).labels().step(1);
		chartOptions.xAxis().add(xAxi);
		
		xAxi = new XAxis();
		xAxi.categories(new ArrayList<String>(Arrays.asList("0-4", "5-9", "10-14", "15-19",
				"20-24", "25-29", "30-34", "35-39", "40-44",
				"45-49", "50-54", "55-59", "60-64", "65-69",                  
				"70-74", "75-79", "80-84", "85-89", "90-94",
				"95-99", "100 + ")));
		xAxi.opposite(true).reversed(false).linkedTo(0).labels().step(1);
		chartOptions.xAxis().add(xAxi);
		
		YAxis yAxi = new YAxis();
		yAxi.title().text(null);
		yAxi.labels().formatter().setFunctionBody("return Math.abs(this.value) + '%';");
		chartOptions.yAxis().add(yAxi);
		
		chartOptions.plotOptions().bar().stacking(Stacking.NORMAL);
		
		chartOptions.tooltip().formatter().setFunctionBody("return \"<b>\" + this.series.name + \", age \" "
				+ "+ this.point.category + \"</b><br/>\" +\r\n" + 
				"\"Population: \" + Highcharts.numberFormat(Math.abs(this.point.y), 0);");
		
		SeriesBar seriesBar = new SeriesBar();
		seriesBar.name("Male");
		seriesBar.dataAsArrayNumber(getSeriesData(1));
		chartOptions.series().add(seriesBar);
		
		seriesBar = new SeriesBar();
		seriesBar.name("Female");
		seriesBar.dataAsArrayNumber(getSeriesData(2));
		chartOptions.series().add(seriesBar);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Number> getSeriesData(int series) {
		List<Number> sourceList;
		ArrayList<Number> array = new ArrayList<Number>();
		
    	if (series == 1) {
    		sourceList = Arrays.asList(-2.2, -2.2, -2.3, -2.5, -2.7, -3.1, -3.2,
    									-3.0, -3.2, -4.3, -4.4, -3.6, -3.1, -2.4,    	          
    									-2.5, -2.3, -1.2, -0.6, -0.2, -0.0, -0.0);
    		array = new ArrayList<Number>(sourceList);
    	}
    	else if (series == 2) {
    		sourceList = Arrays.asList(2.1, 2.0, 2.2, 2.4, 2.6, 3.0, 3.1, 2.9,
    									3.1, 4.1, 4.3, 3.6, 3.4, 2.6, 2.9, 2.9,
    									1.8, 1.2, 0.6, 0.1, 0.0);
    		array = new ArrayList<Number>(sourceList);
    	}
 
    	return array;
    }
}
