package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.LabelsOverflow;
import com.hyjavacharts.model.highcharts.constants.Layout;
import com.hyjavacharts.model.highcharts.constants.TitleAlign;
import com.hyjavacharts.model.highcharts.constants.VerticalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesBar;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class BasicBar extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart().type(ChartType.BAR);
		chartOptions.title().text("Historic World Population by Region");
		chartOptions.subtitle().text("Source: <a href=\"https://en.wikipedia.org/wiki/World_population\">Wikipedia.org</a>");

		XAxis xAxi = new XAxis();
		xAxi.categories(new ArrayList<String>(Arrays.asList("Africa", "America", "Asia", "Europe", "Oceania")));
		chartOptions.xAxis().add(xAxi);

		YAxis yAxi = new YAxis();
		yAxi.min(0).title().text("Population (millions)").align(TitleAlign.HIGH);
		yAxi.labels().overflow(LabelsOverflow.JUSTIFY);
		chartOptions.yAxis().add(yAxi);

		chartOptions.tooltip().valueSuffix(" millions");
		chartOptions.plotOptions().bar().dataLabels().enabled(true);
		chartOptions.credits().enabled(false);
		
		chartOptions.legend().layout(Layout.VERTICAL).align(HorizontalAlign.RIGHT)
			.verticalAlign(VerticalAlign.TOP).x(-40).y(80).floating(true)
			.borderWidth(1).shadowAsBoolean(true)
			.backgroundColor().setColorValue("((Highcharts.theme && Highcharts.theme.legendBackgroundColor) || '#FFFFFF')");
		
		SeriesBar seriesBar = new SeriesBar();
		seriesBar.name("Year 1800");
		seriesBar.dataAsArrayNumber(getSeriesData(1));
		chartOptions.series().add(seriesBar);
		
		seriesBar = new SeriesBar();
		seriesBar.name("Year 1900");
		seriesBar.dataAsArrayNumber(getSeriesData(2));
		chartOptions.series().add(seriesBar);
		
		seriesBar = new SeriesBar();
		seriesBar.name("Year 2012");
		seriesBar.dataAsArrayNumber(getSeriesData(3));
		chartOptions.series().add(seriesBar);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Number> getSeriesData(int series) {
		ArrayList<Number> array = new ArrayList<Number>();
		
    	if (series == 1) {
    		array = new ArrayList<Number>(Arrays.asList(107, 31, 635, 203, 2));
    	}
    	else if (series == 2) {
    		array = new ArrayList<Number>(Arrays.asList(133, 156, 947, 408, 6));
    	}
    	else if (series == 3) {
    		array = new ArrayList<Number>(Arrays.asList(1052, 954, 4250, 740, 38));
    	}

    	return array;
    }
}
