package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesColumn;
import com.hyjavacharts.model.highcharts.series.seriescolumn.Data;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class ColumnWithRotatedLabels extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart().type(ChartType.COLUMN);
		chartOptions.title().text("World's largest cities per 2014");
		chartOptions.subtitle().text("Source: <a href=\"http://en.wikipedia.org/wiki/List_of_cities_proper_by_population\">Wikipedia</a>");
		
		XAxis xAxi = new XAxis();
		xAxi.type(AxisType.CATEGORY)
			.labels().rotation(-45)
			//.style().fontSize("13px");
			.style().setCssValue("{ fontSize: '13px', fontFamily: 'Verdana, sans-serif' }");
		chartOptions.xAxis().add(xAxi);

		YAxis yAxi = new YAxis();
		yAxi.allowDecimals(false)
			.min(0)
			.title().text("Population (millions)");
		chartOptions.yAxis().add(yAxi);
		
		chartOptions.legend().enabled(false);

		chartOptions.tooltip()
			.pointFormat("Population in 2008: <b>{point.y:.1f} millions</b>");

		SeriesColumn seriesColumn = new SeriesColumn();
		seriesColumn.name("Population")
			.dataLabels()
				.enabled(true)
				.rotation(-90)
				.color(new Color("#FFFFFF"))
				.align(HorizontalAlign.RIGHT)
				.format("{point.y:.1f}")
				.y(10)
				//.style().fontSize("13px");
				.style().setCssValue("{ fontSize: '13px', fontFamily: 'Verdana, sans-serif' }");
		seriesColumn.dataAsArrayObject(getSeriesData(1));
		chartOptions.series().add(seriesColumn);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Data> getSeriesData(int series) {
		ArrayList<Data> array = new ArrayList<Data>();
		
		array.add(new Data().name("Shanghai").y(23.7));
		array.add(new Data().name("Lagos").y(16.1));
		array.add(new Data().name("Istanbul").y(14.2));
		array.add(new Data().name("Karachi").y(14.0));
		array.add(new Data().name("Mumbai").y(12.5));
		array.add(new Data().name("Moscow").y(12.1));
		array.add(new Data().name("São Paulo").y(11.8));
		array.add(new Data().name("Beijing").y(11.7));
		array.add(new Data().name("Guangzhou").y(11.1));
		array.add(new Data().name("Delhi").y(11.1));
		array.add(new Data().name("Shenzhen").y(10.5));
		array.add(new Data().name("Seoul").y(10.4));
		array.add(new Data().name("Jakarta").y(10.0));
		array.add(new Data().name("Kinshasa").y(9.3));
		array.add(new Data().name("Tianjin").y(9.3));
		array.add(new Data().name("Tokyo").y(9.0));
		array.add(new Data().name("Cairo").y(8.9));
		array.add(new Data().name("Dhaka").y(8.9));
		array.add(new Data().name("Mexico City").y(8.9));
		array.add(new Data().name("Lima").y(8.9));

    	return array;
    }
}
