package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.Layout;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.constants.VerticalAlign;
import com.hyjavacharts.model.highcharts.constants.ZoomType;
import com.hyjavacharts.model.highcharts.series.SeriesColumn;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class DualAxisLineAndColumn extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart().zoomType(ZoomType.XY);
		chartOptions.title().text("Average Monthly Temperature and Rainfall in Tokyo");
		chartOptions.subtitle().text("Source: WorldClimate.com");

		chartOptions.xAxisSingle()
			.categories(new ArrayList<String>(Arrays.asList("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec")))
			.crosshairAsBoolean(true);

		YAxis yAxi = new YAxis();
		yAxi.labels().format("{value}°C")
			.style().setCssValue("{color: Highcharts.getOptions().colors[1]}");  	//.color(new Color().setJsonString("Highcharts.getOptions().colors[1]"));
		yAxi.title()
			.text("Temperature")
			.style().setCssValue("{color: Highcharts.getOptions().colors[1]}");	// .color(new Color().setJsonString("Highcharts.getOptions().colors[1]"));
		chartOptions.yAxis().add(yAxi);
		
		yAxi = new YAxis();
		yAxi.opposite(true)
			.labels().format("{value} mm")
			.style().setCssValue("{color: Highcharts.getOptions().colors[0]}");  // .color(new Color().setJsonString("Highcharts.getOptions().colors[0]"));
		yAxi.title()
			.text("Rainfall")
			.style().setCssValue("{color: Highcharts.getOptions().colors[0]}"); // .color(new Color().setJsonString("Highcharts.getOptions().colors[0]"));
		chartOptions.yAxis().add(yAxi);

		chartOptions.tooltip().shared(true);

		chartOptions.legend().layout(Layout.VERTICAL).align(HorizontalAlign.LEFT)
			.verticalAlign(VerticalAlign.TOP).x(120).y(100).floating(true)
			.backgroundColor().setColorValue("(Highcharts.theme && Highcharts.theme.legendBackgroundColor) || '#FFFFFF'");
		
		SeriesColumn seriesColumn = new SeriesColumn();
		seriesColumn.type(SeriesType.COLUMN)
			.name("Rainfall")
			.yAxisAsNumber(1)
			.tooltip().valueSuffix(" mm");
		seriesColumn.dataAsArrayNumber(getSeriesData(1));
		chartOptions.series().add(seriesColumn);
		
		SeriesSpline seriesSpline = new SeriesSpline();
		seriesSpline.type(SeriesType.SPLINE)
			.name("Temperature")
			.tooltip().valueSuffix("°C");;
		seriesSpline.dataAsArrayNumber(getSeriesData(2));
		chartOptions.series().add(seriesSpline);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Number> getSeriesData(int series) {
		ArrayList<Number> array = new ArrayList<Number>();
		
    	if (series == 1) {
    		array = new ArrayList<Number>(Arrays.asList(49.9, 71.5, 106.4, 129.2, 144.0, 176.0, 135.6, 148.5, 216.4, 194.1, 95.6, 54.4));
    	}
    	else if (series == 2) {
    		array = new ArrayList<Number>(Arrays.asList(7.0, 6.9, 9.5, 14.5, 18.2, 21.5, 25.2, 26.5, 23.3, 18.3, 13.9, 9.6));
    	}

    	return array;
    }
}
