package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.series.SeriesColumn;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class FixedPlacementColumns extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart().type(ChartType.COLUMN);
		chartOptions.title().text("Efficiency Optimization by Branch");
		
		XAxis xAxi = new XAxis();
		xAxi.categories(new ArrayList<String>(Arrays.asList("Seattle HQ", "San Francisco", "Tokyo")));
		chartOptions.xAxis().add(xAxi);

		YAxis yAxi = new YAxis();
		yAxi.min(0).title().text("Employees");
		chartOptions.yAxis().add(yAxi);
		yAxi = new YAxis();
		yAxi.opposite(true).title().text("Profit (millions)");
		chartOptions.yAxis().add(yAxi);

		chartOptions.legend().shadowAsBoolean(false);
		chartOptions.tooltip().shared(true);
		
		chartOptions.plotOptions().column().grouping(false).shadowAsBoolean(false).borderWidth(0);

		SeriesColumn seriesColumn = new SeriesColumn();
		seriesColumn.name("Employees")
			.color(new Color("rgba(165,170,217,1)"))
			.pointPadding(0.3)
			.pointPlacementAsNumber(-0.2);
		seriesColumn.dataAsArrayNumber(getSeriesData(1));
		chartOptions.series().add(seriesColumn);

		seriesColumn = new SeriesColumn();
		seriesColumn.name("Employees Optimized")
			.color(new Color("rgba(126,86,134,.9)"))
			.pointPadding(0.4)
			.pointPlacementAsNumber(-0.2);
		seriesColumn.dataAsArrayNumber(getSeriesData(2));
		chartOptions.series().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.name("Profit")
			.color(new Color("rgba(248,161,63,1)"))
			.pointPadding(0.3)
			.pointPlacementAsNumber(0.2)
			.yAxisAsNumber(1)
			.tooltip().valuePrefix("$").valueSuffix(" M");
		seriesColumn.dataAsArrayNumber(getSeriesData(3));
		chartOptions.series().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.name("Profit Optimized")
			.color(new Color("rgba(186,60,61,.9)"))
			.pointPadding(0.4)
			.pointPlacementAsNumber(0.2)
			.yAxisAsNumber(1)
			.tooltip().valuePrefix("$").valueSuffix(" M");
		seriesColumn.dataAsArrayNumber(getSeriesData(4));
		chartOptions.series().add(seriesColumn);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Number> getSeriesData(int series) {
		ArrayList<Number> array = new ArrayList<Number>();
		
    	if (series == 1) {
    		array = new ArrayList<Number>(Arrays.asList(150, 73, 20));
    	}
    	else if (series == 2) {
    		array = new ArrayList<Number>(Arrays.asList(140, 90, 40));
    	}
    	else if (series == 3) {
    		array = new ArrayList<Number>(Arrays.asList(183.6, 178.8, 198.5));
    	}
    	else if (series == 4) {
    		array = new ArrayList<Number>(Arrays.asList(203.6, 198.8, 208.5));
    	}

    	return array;
    }
}
