package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.Stop;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesHeatmap;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class LargeHeatMap extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart().type(ChartType.HEATMAP)
			.margin(new ArrayList<Number>(Arrays.asList(60, 10, 80, 50)));

		chartOptions.boost().useGPUTranslations(true);

		chartOptions.title().text("Highcharts heat map")
			.align(HorizontalAlign.LEFT)
			.x(40);

		chartOptions.subtitle().text("Temperature variation by day and hour through 2013")
			.align(HorizontalAlign.LEFT)
			.x(40);
		
		chartOptions.xAxisSingle()
			.type(AxisType.DATETIME)
			.min(Date.UTC(2013-1900, 0, 1, 0, 0, 0))
			.max(Date.UTC(2014-1900, 0, 1, 0, 0, 0))
			.showLastLabel(false)
			.tickLength(16)
			.labels()
				.align(HorizontalAlign.LEFT)
				.x(5)
				.y(14)
				.format("{value:%B}");
		
		chartOptions.yAxisSingle().title().text(null);
		chartOptions.yAxisSingle()
			.minPadding(0)
			.maxPadding(0)
			.startOnTick(false)
			.endOnTick(false)
			.tickPositions(new ArrayList<Number>(Arrays.asList(0, 6, 12, 18, 24)))
			.tickWidth(1)
			.min(0)
			.max(23)
			.reversed(true)
			.labels().format("{value}:00");
		
		chartOptions.colorAxis()
			.min(-15)
			.max(25)
			.startOnTick(false)
			.endOnTick(false)
			.stops(new ArrayList<Stop>(Arrays.asList(new Stop(0, new Color("#3060cf")), 
																 new Stop(0.5, new Color("#fffbbc")),
																 new Stop(0.9, new Color("#c4463a")),
																 new Stop(1, new Color("#c4463a")))))
			.labels().format("{value}℃");
		
		SeriesHeatmap seriesHeatmap = new SeriesHeatmap();
		seriesHeatmap//.boostThreshold(100)
			.borderWidth(0)
			//.nullColor(new Color("#EFEFEF"))
			.colsize(24 * 36e5)
			.tooltip().headerFormat("Temperature<br/>")
				.pointFormat("{point.x:%e %b, %Y} {point.y}:00: <b>{point.value} ℃</b>");
		seriesHeatmap.dataAsArrayJavaObject(getSeriesData(1));
		chartOptions.series().add(seriesHeatmap);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Object> getSeriesData(int series) {
		ArrayList<Object> array2 = new ArrayList<Object>();

		array2.addAll(new LargeHeatMapData1().getSeriesData());
		array2.addAll(new LargeHeatMapData2().getSeriesData());
		array2.addAll(new LargeHeatMapData3().getSeriesData());
		array2.addAll(new LargeHeatMapData4().getSeriesData());

		ArrayList<Object> array = new ArrayList<Object>();
				
		int time = 0;
		int year = 2013-1900;
		int month = 0;
		int day = 1;
		
		for(int i = 1; i < 7950; i++) {
			array.add(new ArrayList<Object>(Arrays.asList(Date.UTC(year, month, day, 0, 0, 0), time , array2.get(i))));
			
			time++;
			if (time == 24) {
				time = 0;
				day++;
			}
			
			if (day == 30) {
				day = 1;
				month++;
			}
       }

    	return array;
    }
}
