package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.Stop;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.constants.Shape;
import com.hyjavacharts.model.highcharts.pane.Background;
import com.hyjavacharts.model.highcharts.series.SeriesSolidgauge;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class SolidGauge extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
				
		chartOptions.chart().type(ChartType.SOLIDGAUGE);
		chartOptions.title().text(null);
		chartOptions.paneSingle().centerAsArrayString().add("50%");
		chartOptions.paneSingle().centerAsArrayString().add("85%");
		chartOptions.paneSingle().sizeAsString("140%").startAngle(-90).endAngle(90);
		chartOptions.tooltip().enabled(false);
		
		Background b = new Background()
				.innerRadiusAsString("60%")
				.outerRadiusAsString("100%")
				.shape(Shape.ARC)
				.backgroundColor(new Color().setColorValue("(Highcharts.theme && Highcharts.theme.background2) || '#EEE'"));
		chartOptions.paneSingle().background().add(b);
		
		YAxis yAxi = new YAxis();
		yAxi.lineWidth(0).tickAmount(2).min(0).max(200).title().text("Speed").y(-70); 	
		yAxi.minorTickIntervalAsString(null);		// cannot do minorTickInterval: null,
		yAxi.labels().y(16);
		yAxi.stops().add(new Stop(0.1, new Color("#55BF3B")));
		yAxi.stops().add(new Stop(0.5, new Color("#DDDF0D")));
		yAxi.stops().add(new Stop(0.9, new Color("#DF5353")));
		chartOptions.yAxis().add(yAxi);
		
		chartOptions.plotOptions()
			.solidgauge()
				.dataLabels()
					.y(5).borderWidth(0); //.useHTML(true); // not in v6.0.1
		
		chartOptions.credits().enabled(false);
		
		String format = "<div style=\"text-align:center\"><span style=\"font-size:25px;color:" 
				+ "((Highcharts.theme && Highcharts.theme.contrastTextColor) || 'black') + '\">{y}</span><br/>"
				+ "<span style=\"font-size:12px;color:silver\">km/h</span></div>";
		
		SeriesSolidgauge seriesSolidgauge = new SeriesSolidgauge();
		seriesSolidgauge
			.type(SeriesType.SOLIDGAUGE)
			.name("Speed")
			.dataLabels().format(format);
		seriesSolidgauge.dataAsArrayNumber(new ArrayList<Number>(Arrays.asList(80)));
		chartOptions.series().add(seriesSolidgauge);
		
		return highChart;
	}

}
