package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.LabelsOverflow;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.hyjavacharts.model.highcharts.yaxis.PlotBands;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class SplineWithPlotBands extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();

		chartOptions.chart().type(ChartType.SPLINE);
		chartOptions.title().text("Wind speed during two days");
		chartOptions.subtitle().text("May 31 and and June 1, 2015 at two locations in Vik i Sogn, Norway");

		XAxis xAxi = new XAxis();
		xAxi.type(AxisType.DATETIME).labels().overflow(LabelsOverflow.JUSTIFY);
		chartOptions.xAxis().add(xAxi);

		YAxis yAxi = new YAxis();
		yAxi.title().text("Wind speed (m/s)");
		yAxi.minorGridLineWidth(0).gridLineWidth(0);//.alternateGridColor(new Color(null));
		
		PlotBands pb = new PlotBands();
		pb.from(0.3).to(1.5).color(new Color("rgba(68, 170, 213, 0.1)")).label().text("Light air").style().setJsValue("{ color: '#606060' }");
		yAxi.plotBands().add(pb);

		pb = new PlotBands();
		pb.from(1.5).to(3.3).color(new Color("rgba(0, 0, 0, 0)")).label().text("Light breeze").style().setJsValue("{ color: '#606060' }");
		yAxi.plotBands().add(pb);
		
		pb = new PlotBands();
		pb.from(3.3).to(5.5).color(new Color("rgba(68, 170, 213, 0.1)")).label().text("Gentle breeze").style().setJsValue("{ color: '#606060' }");
		yAxi.plotBands().add(pb);
		
		pb = new PlotBands();
		pb.from(5.5).to(8).color(new Color("rgba(0, 0, 0, 0)")).label().text("Moderate breeze").style().setJsValue("{ color: '#606060' }");
		yAxi.plotBands().add(pb);

		pb = new PlotBands();
		pb.from(8).to(11).color(new Color("rgba(68, 170, 213, 0.1)")).label().text("Fresh breeze").style().setJsValue("{ color: '#606060' }");
		yAxi.plotBands().add(pb);
		
		pb = new PlotBands();
		pb.from(11).to(14).color(new Color("rgba(0, 0, 0, 0)")).label().text("Strong breeze").style().setJsValue("{ color: '#606060' }");
		yAxi.plotBands().add(pb);
		
		pb = new PlotBands();
		pb.from(14).to(15).color(new Color("rgba(68, 170, 213, 0.1)")).label().text("High wind").style().setJsValue("{ color: '#606060' }");
		yAxi.plotBands().add(pb);
		
		chartOptions.yAxis().add(yAxi);

		chartOptions.tooltip().valueSuffix(" m/s");

		chartOptions.plotOptions().spline().lineWidth(4).states().hover().lineWidth(5);
		chartOptions.plotOptions().spline().pointInterval(3600000).pointStart(Date.UTC(2015-1900, 4, 31, 0, 0, 0)).marker().enabled(false);
		chartOptions.navigation().menuItemStyle().setCssValue("{ fontSize: '10px' }");
		
		SeriesSpline seriesSpline = new SeriesSpline();
		seriesSpline.name("Hestavollane");
		seriesSpline.dataAsArrayNumber(getSeriesData(1));
		chartOptions.series().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.name("Vik");
		seriesSpline.dataAsArrayNumber(getSeriesData(2));
		chartOptions.series().add(seriesSpline);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	public ArrayList<Number> getSeriesData(int series) {
		ArrayList<Number> array = new ArrayList<Number>();

		if (series == 1) {
			List<Number> sourceList = Arrays.asList(0.2, 0.8, 0.8, 0.8, 1, 1.3, 1.5, 2.9, 1.9, 2.6, 1.6, 3, 4, 3.6, 4.5, 4.2, 4.5, 4.5, 4, 3.1, 2.7, 4, 2.7, 2.3, 2.3, 4.1, 7.7, 7.1, 5.6, 6.1, 5.8, 8.6, 7.2, 9, 10.9, 11.5, 11.6, 11.1, 12, 12.3, 10.7, 9.4, 9.8, 9.6, 9.8, 9.5, 8.5, 7.4, 7.6);
    		array = new ArrayList<Number>(sourceList);
		}
		else {
			List<Number> sourceList = Arrays.asList(0, 0, 0.6, 0.9, 0.8, 0.2, 0, 0, 0, 0.1, 0.6, 0.7, 0.8, 0.6, 0.2, 0, 0.1, 0.3, 0.3, 0, 0.1, 0, 0, 0, 0.2, 0.1, 0, 0.3, 0, 0.1, 0.2, 0.1, 0.3, 0.3, 0, 3.1, 3.1, 2.5, 1.5, 1.9, 2.1, 1, 2.3, 1.9, 1.2, 0.7, 1.3, 0.4, 0.3);
    		array = new ArrayList<Number>(sourceList);
		}
		
    	return array;
    }
}
