package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.Stacking;
import com.hyjavacharts.model.highcharts.constants.VerticalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesColumn;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class StackedColumn extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart().type(ChartType.COLUMN);
		chartOptions.title().text("Stacked column chart");

		XAxis xAxi = new XAxis();
		xAxi.categories(new ArrayList<String>(Arrays.asList("Apples", "Oranges", "Pears", "Grapes", "Bananas")));
		chartOptions.xAxis().add(xAxi);

		YAxis yAxi = new YAxis();
		yAxi.min(0).title().text("Total fruit consumption");
		yAxi.stackLabels()
			.enabled(true)
			.style()
				//.fontWeight("bold")
				//.color(new Color().setJsonString("(Highcharts.theme && Highcharts.theme.textColor) || 'gray'")); 
				.setCssValue("{ fontWeight: 'bold', color: (Highcharts.theme && Highcharts.theme.textColor) || 'gray' }");
		chartOptions.yAxis().add(yAxi);
		
		chartOptions.legend()
			.align(HorizontalAlign.RIGHT)
			.x(-30)
			.verticalAlign(VerticalAlign.TOP)
			.y(25)
			.floating(true)
			.backgroundColor(new Color().setColorValue("(Highcharts.theme && Highcharts.theme.background2) || 'white'"))
			.borderColor(new Color("#CCC"))
			.borderWidth(1)
			.shadowAsBoolean(false);
		
		chartOptions.tooltip()
			.headerFormat("<b>{point.x}</b><br/>")
			.pointFormat("{series.name}: {point.y}<br/>Total: {point.stackTotal}");
		
		chartOptions.plotOptions().column()
			.stacking(Stacking.NORMAL)
			.dataLabels()
				.enabled(true)
				.color(new Color().setColorValue("(Highcharts.theme && Highcharts.theme.dataLabelsColor) || 'white'"));
		
		SeriesColumn seriesColumn = new SeriesColumn();
		seriesColumn.name("John");
		seriesColumn.dataAsArrayNumber(getSeriesData(1));
		chartOptions.series().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.name("Jane");
		seriesColumn.dataAsArrayNumber(getSeriesData(2));
		chartOptions.series().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.name("Joe");
		seriesColumn.dataAsArrayNumber(getSeriesData(3));
		chartOptions.series().add(seriesColumn);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Number> getSeriesData(int series) {
		ArrayList<Number> array = new ArrayList<Number>();
		
    	if (series == 1) {
    		array = new ArrayList<Number>(Arrays.asList(5, 3, 4, 7, 2));
    	}
    	else if (series == 2) {
    		array = new ArrayList<Number>(Arrays.asList(2, 2, 3, 2, 1));
    	}
    	else if (series == 3) {
    		array = new ArrayList<Number>(Arrays.asList(3, 4, 4, 2, 5));
    	}

    	return array;
    }
}
