package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Date;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.hyjavacharts.model.highcharts.series.seriesspline.Data;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class TimeDataWithIrregularIntervals extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();

		chartOptions.chart().type(ChartType.SPLINE);
		chartOptions.title().text("Snow depth at Vikjafjellet, Norway");
		chartOptions.subtitle().text("Irregular time data in Highcharts JS");

		XAxis xAxi = new XAxis();
		xAxi.type(AxisType.DATETIME)
			.dateTimeLabelFormats().setJsValue("{ month: '%e. %b', year: '%b' }");
			//.dateTimeLabelFormats().month("%e. %b").year("%b");
		xAxi.title().text("Date");
		chartOptions.xAxis().add(xAxi);

		YAxis yAxi = new YAxis();
		yAxi
			.min(0)
			.title().text("Snow depth (m)");
		chartOptions.yAxis().add(yAxi);
		
		chartOptions.tooltip().headerFormat("<b>{series.name}</b><br>").pointFormat("{point.x:%e. %b}: {point.y:.2f} m");
		chartOptions.plotOptions().spline().marker().enabled(true);
		
		SeriesSpline seriesSpline = new SeriesSpline();
		seriesSpline.name("Winter 2012-2013");
		seriesSpline.dataAsArrayObject(getSeriesData(1));
		chartOptions.series().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.name("Winter 2013-2014");
		seriesSpline.dataAsArrayObject(getSeriesData(2));
		chartOptions.series().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.name("Winter 2014-2015");
		seriesSpline.dataAsArrayObject(getSeriesData(3));
		chartOptions.series().add(seriesSpline);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	public ArrayList<Data> getSeriesData(int series) {
		ArrayList<Data> array = new ArrayList<Data>();
		
    	if (series == 1) {
    		array.add(new Data().x(Date.UTC(1970, 9, 21,0 , 0, 0)).y( 0));
            array.add(new Data().x(Date.UTC(1970, 10, 4,0 , 0, 0)).y( 0.28));
            array.add(new Data().x(Date.UTC(1970, 10, 9,0 , 0, 0)).y( 0.25));
            array.add(new Data().x(Date.UTC(1970, 10, 27,0 , 0, 0)).y( 0.2));
            array.add(new Data().x(Date.UTC(1970, 11, 2,0 , 0, 0)).y( 0.28));
            array.add(new Data().x(Date.UTC(1970, 11, 26,0 , 0, 0)).y( 0.28));
            array.add(new Data().x(Date.UTC(1970, 11, 29,0 , 0, 0)).y( 0.47));
            array.add(new Data().x(Date.UTC(1971, 0, 11,0 , 0, 0)).y( 0.79));
            array.add(new Data().x(Date.UTC(1971, 0, 26,0 , 0, 0)).y( 0.72));
            array.add(new Data().x(Date.UTC(1971, 1, 3,0 , 0, 0)).y( 1.02));
            array.add(new Data().x(Date.UTC(1971, 1, 11,0 , 0, 0)).y( 1.12));
            array.add(new Data().x(Date.UTC(1971, 1, 25,0 , 0, 0)).y( 1.2));
            array.add(new Data().x(Date.UTC(1971, 2, 11,0 , 0, 0)).y( 1.18));
            array.add(new Data().x(Date.UTC(1971, 3, 11,0 , 0, 0)).y( 1.19));
            array.add(new Data().x(Date.UTC(1971, 4, 1,0 , 0, 0)).y( 1.85));
            array.add(new Data().x(Date.UTC(1971, 4, 5,0 , 0, 0)).y( 2.22));
            array.add(new Data().x(Date.UTC(1971, 4, 19,0 , 0, 0)).y( 1.15));
            array.add(new Data().x(Date.UTC(1971, 5, 3,0 , 0, 0)).y( 0));
    	}
    	else if (series == 2) {
    		array.add(new Data().x(Date.UTC(1970, 9, 29,0 , 0, 0)).y( 0));
            array.add(new Data().x(Date.UTC(1970, 10, 9,0 , 0, 0)).y( 0.4));
            array.add(new Data().x(Date.UTC(1970, 11, 1,0 , 0, 0)).y( 0.25));
            array.add(new Data().x(Date.UTC(1971, 0, 1,0 , 0, 0)).y( 1.66));
            array.add(new Data().x(Date.UTC(1971, 0, 10,0 , 0, 0)).y( 1.8));
            array.add(new Data().x(Date.UTC(1971, 1, 19,0 , 0, 0)).y( 1.76));
            array.add(new Data().x(Date.UTC(1971, 2, 25,0 , 0, 0)).y( 2.62));
            array.add(new Data().x(Date.UTC(1971, 3, 19,0 , 0, 0)).y( 2.41));
            array.add(new Data().x(Date.UTC(1971, 3, 30,0 , 0, 0)).y( 2.05));
            array.add(new Data().x(Date.UTC(1971, 4, 14,0 , 0, 0)).y( 1.7));
            array.add(new Data().x(Date.UTC(1971, 4, 24,0 , 0, 0)).y( 1.1));
            array.add(new Data().x(Date.UTC(1971, 5, 10,0 , 0, 0)).y( 0));
    	}
    	else {
    		array.add(new Data().x(Date.UTC(1970, 10, 25,0 , 0, 0)).y( 0));
            array.add(new Data().x(Date.UTC(1970, 11, 6,0 , 0, 0)).y( 0.25));
            array.add(new Data().x(Date.UTC(1970, 11, 20,0 , 0, 0)).y( 1.41));
            array.add(new Data().x(Date.UTC(1970, 11, 25,0 , 0, 0)).y( 1.64));
            array.add(new Data().x(Date.UTC(1971, 0, 4,0 , 0, 0)).y( 1.6));
            array.add(new Data().x(Date.UTC(1971, 0, 17,0 , 0, 0)).y( 2.55));
            array.add(new Data().x(Date.UTC(1971, 0, 24,0 , 0, 0)).y( 2.62));
            array.add(new Data().x(Date.UTC(1971, 1, 4,0 , 0, 0)).y( 2.5));
            array.add(new Data().x(Date.UTC(1971, 1, 14,0 , 0, 0)).y( 2.42));
            array.add(new Data().x(Date.UTC(1971, 2, 6,0 , 0, 0)).y( 2.74));
            array.add(new Data().x(Date.UTC(1971, 2, 14,0 , 0, 0)).y( 2.62));
            array.add(new Data().x(Date.UTC(1971, 2, 24,0 , 0, 0)).y( 2.6));
            array.add(new Data().x(Date.UTC(1971, 3, 2,0 , 0, 0)).y( 2.81));
            array.add(new Data().x(Date.UTC(1971, 3, 12,0 , 0, 0)).y( 2.63));
            array.add(new Data().x(Date.UTC(1971, 3, 28,0 , 0, 0)).y( 2.77));
            array.add(new Data().x(Date.UTC(1971, 4, 5,0 , 0, 0)).y( 2.68));
            array.add(new Data().x(Date.UTC(1971, 4, 10,0 , 0, 0)).y( 2.56));
            array.add(new Data().x(Date.UTC(1971, 4, 15,0 , 0, 0)).y( 2.39));
            array.add(new Data().x(Date.UTC(1971, 4, 20,0 , 0, 0)).y( 2.3));
            array.add(new Data().x(Date.UTC(1971, 5, 5,0 , 0, 0)).y( 2));
            array.add(new Data().x(Date.UTC(1971, 5, 10,0 , 0, 0)).y( 1.85));
            array.add(new Data().x(Date.UTC(1971, 5, 15,0 , 0, 0)).y( 1.49));
            array.add(new Data().x(Date.UTC(1971, 5, 23,0 , 0, 0)).y( 1.08));
    	}

    	return array;
    }
}
