package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.Layout;
import com.hyjavacharts.model.highcharts.constants.VerticalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesArea;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class AreaWithMissingPoints extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart().type(ChartType.AREA)
			.spacingBottom(30);
		
		chartOptions.title().text("Fruit consumption *");
		chartOptions.subtitle()
			.floating(true)
			.align(HorizontalAlign.RIGHT)
			.verticalAlign(VerticalAlign.BOTTOM)
			.y(15)
			.text("* Jane\\'s banana consumption is unknown");

		chartOptions.legend()
			.layout(Layout.VERTICAL)
			.align(HorizontalAlign.LEFT)
			.verticalAlign(VerticalAlign.TOP)
			.x(150)
			.y(100)
			.floating(true)
			.borderWidth(1)
			.backgroundColor(new Color().setColorValue("(Highcharts.theme && Highcharts.theme.legendBackgroundColor) || '#FFFFFF'"));
		
		chartOptions.xAxisSingle().categories(new ArrayList<String>(Arrays.asList("Apples", "Pears", "Oranges", "Bananas", "Grapes", "Plums", "Strawberries", "Raspberries")));
		
		chartOptions.yAxisSingle().title().text("Y-Axis");
		chartOptions.yAxisSingle().labels().formatter().setFunctionBody("return this.value;");

		chartOptions.tooltip().formatter().setFunctionBody("return '<b>' + this.series.name + '</b><br/>' + this.x + ': ' + this.y;");

		chartOptions.plotOptions().area().fillOpacity(0.5);
	
		chartOptions.credits().enabled(false);
		
		SeriesArea seriesArea = new SeriesArea();
		seriesArea.name("John");
		seriesArea.dataAsArrayNumber(getSeriesData(1));
		chartOptions.series().add(seriesArea);
		
		seriesArea = new SeriesArea();
		seriesArea.name("Jane");
		seriesArea.dataAsArrayNumber(getSeriesData(2));
		chartOptions.series().add(seriesArea);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Number> getSeriesData(int series) {
		ArrayList<Number> array = new ArrayList<Number>();
		
    	if (series == 1) {
    		array = new ArrayList<Number>(Arrays.asList(0, 1, 4, 4, 5, 2, 3, 7));
    	}
    	else if (series == 2) {
    		array = new ArrayList<Number>(Arrays.asList(1, 0, 3, null, 3, 1, 2, 1));
    	}

    	return array;
    }
}
