package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.TitleAlign;
import com.hyjavacharts.model.highcharts.series.SeriesColumn;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class BasicColumn extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart().type(ChartType.COLUMN);
		chartOptions.title().text("Monthly Average Rainfall");
		chartOptions.subtitle().text("Source: WorldClimate.com");

		XAxis xAxi = new XAxis();
		xAxi.crosshairAsBoolean(true)
			.categories(new ArrayList<String>
				(Arrays.asList("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec")));

		chartOptions.xAxis().add(xAxi);

		YAxis yAxi = new YAxis();
		yAxi.min(0).title().text("Population (millions)").align(TitleAlign.HIGH);
		chartOptions.yAxis().add(yAxi);
		
		chartOptions.tooltip()
			.headerFormat("<span style=\"font-size:10px\">{point.key}</span><table>")
			.pointFormat("<tr><td style=\"color:{series.color};padding:0\">{series.name}: </td>" 
						+ "<td style=\"padding:0\"><b>{point.y:.1f} mm</b></td></tr>")
			.footerFormat("</table>")
			.shared(true)
			.useHTML(true);
		
		chartOptions.plotOptions().column().pointPadding(0.2).borderWidth(0);
		
		SeriesColumn seriesColumn = new SeriesColumn();
		seriesColumn.name("Tokyo");
		seriesColumn.dataAsArrayNumber(getSeriesData(1));
		chartOptions.series().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.name("New York");
		seriesColumn.dataAsArrayNumber(getSeriesData(2));
		chartOptions.series().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.name("London");
		seriesColumn.dataAsArrayNumber(getSeriesData(3));
		chartOptions.series().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn.name("Berlin");
		seriesColumn.dataAsArrayNumber(getSeriesData(4));
		chartOptions.series().add(seriesColumn);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	public ArrayList<Number> getSeriesData(int series) {
		ArrayList<Number> array = new ArrayList<Number>();
		
    	if (series == 1) {
    		array = new ArrayList<Number>(Arrays.asList(49.9, 71.5, 106.4, 129.2, 144.0, 176.0, 135.6, 148.5, 216.4, 194.1, 95.6, 54.4));
    	}
    	else if (series == 2) {
    		array = new ArrayList<Number>(Arrays.asList(83.6, 78.8, 98.5, 93.4, 106.0, 84.5, 105.0, 104.3, 91.2, 83.5, 106.6, 92.3));
    	}
    	else if (series == 3) {
    		array = new ArrayList<Number>(Arrays.asList(48.9, 38.8, 39.3, 41.4, 47.0, 48.3, 59.0, 59.6, 52.4, 65.2, 59.3, 51.2));
    	}
    	else if (series == 4) {
    		array = new ArrayList<Number>(Arrays.asList(42.4, 33.2, 34.5, 39.7, 52.6, 75.5, 57.4, 60.4, 47.6, 39.1, 46.8, 51.1));
    	}

    	return array;
    }
}
