package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.series.SeriesBoxplot;
import com.hyjavacharts.model.highcharts.series.SeriesScatter;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class BoxPlot extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart().type(ChartType.BOXPLOT);
		chartOptions.title().text("Highcharts Box Plot Example");

		chartOptions.legend().enabled(false);
		
		chartOptions.xAxisSingle()
			.categories(new ArrayList<String>(Arrays.asList("1", "2", "3", "4", "5")))
			.title().text("Experiment No.");

		chartOptions.yAxisSingle()
			.title().text("Observations");
		chartOptions.yAxisSingle()
			.plotLinesSingle()
				.value(932)
				.color(new Color("red"))
				.width(1)
				.label().text("Theoretical mean: 932")
					.align(HorizontalAlign.CENTER)
					.style().setJsValue("{ color: 'gray' }");

		SeriesBoxplot seriesBoxplot = new SeriesBoxplot();
		seriesBoxplot.name("Observations");
		seriesBoxplot.tooltip().headerFormat("<em>Experiment No {point.key}</em><br/>");
		seriesBoxplot.dataAsArrayJavaObject(getSeriesData(1));
		chartOptions.series().add(seriesBoxplot);
		
		SeriesScatter seriesScatter = new SeriesScatter();
		seriesScatter.type(SeriesType.SCATTER)
			.name("Outlier")
			.color(new Color().setColorValue("Highcharts.getOptions().colors[0]"))
			.marker()
				.fillColor(new Color("white"))
				.lineWidth(1)
				.lineColor(new Color().setColorValue("Highcharts.getOptions().colors[0]"));
		seriesScatter.tooltip().pointFormat("Observation: {point.y}");
		seriesScatter.dataAsArrayJavaObject(getSeriesData(2));
		chartOptions.series().add(seriesScatter);
				
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Object> getSeriesData(int series) {
		ArrayList<Object> array = new ArrayList<Object>();
		
		if (series == 1) {
	    	array.add(new ArrayList<Number>(Arrays.asList(760, 801, 848, 895, 965)));
	    	array.add(new ArrayList<Number>(Arrays.asList(733, 853, 939, 980, 1080)));
	    	array.add(new ArrayList<Number>(Arrays.asList(714, 762, 817, 870, 918)));
	    	array.add(new ArrayList<Number>(Arrays.asList(724, 802, 806, 871, 950)));
	    	array.add(new ArrayList<Number>(Arrays.asList(834, 836, 864, 882, 910)));
		}
		else {
			array.add(new ArrayList<Number>(Arrays.asList(0, 644)));
	    	array.add(new ArrayList<Number>(Arrays.asList(4, 718)));
	    	array.add(new ArrayList<Number>(Arrays.asList(4, 951)));
	    	array.add(new ArrayList<Number>(Arrays.asList(4, 969)));
		}

    	return array;
    }
}
