package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.DashStyle;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.ZoomType;
import com.hyjavacharts.model.highcharts.series.SeriesBubble;
import com.hyjavacharts.model.highcharts.series.seriesbubble.Data;
import com.hyjavacharts.model.highcharts.xaxis.PlotLines;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class BubbleChart extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart()
			.type(ChartType.BUBBLE)
			.plotBorderWidth(1)
			.zoomType(ZoomType.XY);
		chartOptions.title()
			.text("Sugar and fat intake per country");
		chartOptions.subtitle()
			.text("Source: <a href=\"http://www.euromonitor.com/\">Euromonitor</a> and <a href=\"https://data.oecd.org/\">OECD</a>");
		
		chartOptions.legend().enabled(false);
		
		XAxis xAxi = new XAxis();
		xAxi.gridLineWidth(1)
			.title().text("Daily fat intake");
		xAxi.labels()
			.format("{value} gr");
		
		PlotLines pl = new PlotLines();
		pl.color().setColor(Color.BLACK);
		pl.dashStyle(DashStyle.DOT)
			.width(2).value(65).zIndex(3).label().rotation(0)
			.y(15).text("Safe fat intake 65g/day")
			.style().setJsValue("{ fontStyle: 'italic' }");
		
		xAxi.plotLines().add(pl);
		chartOptions.xAxis().add(xAxi);
		
		YAxis yAxi = new YAxis();
		yAxi.startOnTick(false)
			.endOnTick(false)
			.title().text("Daily sugar intake");
		yAxi.labels().format("{value} gr");
		yAxi.maxPadding(0.2);
		
		com.hyjavacharts.model.highcharts.yaxis.PlotLines ypl = 
				new com.hyjavacharts.model.highcharts.yaxis.PlotLines();
		ypl.color().setColor(Color.BLACK);
		ypl.dashStyle(DashStyle.DOT)		
			.width(2)
			.value(50)
			.zIndex(3)
			.label()
				.align(HorizontalAlign.RIGHT)
				.x(-10)
				.text("Safe sugar intake 50g/day")
				.style().setJsValue("{ fontStyle: 'italic' }");
		yAxi.plotLines().add(ypl);
		chartOptions.yAxis().add(yAxi);

		chartOptions.tooltip()
			.useHTML(true)
			.headerFormat("<table>")
			.pointFormat("<tr><th colspan=\"2\"><h3>{point.description}</h3></th></tr>" +
					"<tr><th>Fat intake:</th><td>{point.x}g</td></tr>" +
					"<tr><th>Sugar intake:</th><td>{point.y}g</td></tr>" +
					"<tr><th>Obesity (adults):</th><td>{point.z}%</td></tr>")
			.footerFormat("</table>")
			.followPointer(true);
		
		chartOptions.plotOptions()
			.bubble().dataLabels().enabled(true).format("{point.name}");
		
		SeriesBubble seriesBubble = new SeriesBubble();
		seriesBubble.dataAsArrayObject(getSeriesData(1));
		chartOptions.series().add(seriesBubble);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Data> getSeriesData(int series) {
		ArrayList<Data> array = new ArrayList<Data>();
		
		array.add(new Data().x(95).y(95).z(13.8).name("BE").description("Belgium"));
		array.add(new Data().x(86.5).y(102.9).z(14.7).name("DE").description("Germany"));
		array.add(new Data().x(80.8).y(91.5).z(15.8).name("FI").description("Finland"));
		array.add(new Data().x(80.4).y(102.5).z(12).name("NL").description("Netherlands"));
		array.add(new Data().x(80.3).y(86.1).z(11.8).name("SE").description("Sweden"));
		array.add(new Data().x(78.4).y(70.1).z(16.6).name("ES").description("Spain"));
		array.add(new Data().x(74.2).y(68.5).z(14.5).name("FR").description("France"));
		array.add(new Data().x(73.5).y(83.1).z(10).name("NO").description("Norway"));
		array.add(new Data().x(71).y(93.2).z(24.7).name("UK").description("United Kingdom"));
		array.add(new Data().x(69.2).y(57.6).z(10.4).name("IT").description("Italy"));
		array.add(new Data().x(68.6).y(20).z(16).name("RU").description("Russia"));
		array.add(new Data().x(65.5).y(126.4).z(35.3).name("US").description("United States"));
		array.add(new Data().x(65.4).y(50.8).z(28.5).name("HU").description("Hungary"));
		array.add(new Data().x(63.4).y(51.8).z(15.4).name("PT").description("Portugal"));
		array.add(new Data().x(64).y(82.9).z(31.3).name("NZ").description("New Zealand"));

    	return array;
    }
}
