package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.labels.Items;
import com.hyjavacharts.model.highcharts.series.SeriesColumn;
import com.hyjavacharts.model.highcharts.series.SeriesPie;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.hyjavacharts.model.highcharts.series.seriespie.Data;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class ColumnLineAndPie extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.title().text("Combination chart");
		
		XAxis xAxi = new XAxis();
		xAxi.categories(new ArrayList<String>(Arrays.asList("Apples", "Oranges", "Pears", "Bananas", "Plums")));
		chartOptions.xAxis().add(xAxi);
		
		Items item = new Items();
		item.html("Total fruit consumption")
			.style()
				.setCssValue("{ left: '50px', top: '18px', color: (Highcharts.theme && Highcharts.theme.textColor) || 'black' }");
		chartOptions.labels().items().add(item);
		
		SeriesColumn seriesColumn = new SeriesColumn();
		seriesColumn
			.type(SeriesType.COLUMN)
			.name("Jane");
		seriesColumn.dataAsArrayNumber(getSeriesData(1));
		chartOptions.series().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn
			.type(SeriesType.COLUMN)
			.name("John");
		seriesColumn.dataAsArrayNumber(getSeriesData(2));
		chartOptions.series().add(seriesColumn);
		
		seriesColumn = new SeriesColumn();
		seriesColumn
			.type(SeriesType.COLUMN)
			.name("Joe");
		seriesColumn.dataAsArrayNumber(getSeriesData(3));
		chartOptions.series().add(seriesColumn);

		SeriesSpline seriesSpline = new SeriesSpline();
		seriesSpline
			.type(SeriesType.SPLINE)
			.name("Average");
		seriesSpline.marker()
			.lineWidth(2)
			.fillColor(new Color("white"))
			.lineColor().setColorValue("Highcharts.getOptions().colors[3]");
		seriesSpline.dataAsArrayNumber(getSeriesData(4));
		chartOptions.series().add(seriesSpline);
		
		SeriesPie seriesPie = new SeriesPie();
		seriesPie
			.type(SeriesType.PIE)
			.name("Total consumption")
			.centerAsArrayNumber(getSeriesData(5))
			.sizeAsNumber(100)
			.showInLegend(false)
			.dataLabels().enabled(false);
		seriesPie.dataAsArrayObject(getPieData(1));
		chartOptions.series().add(seriesPie);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	public ArrayList<Number> getSeriesData(int series) {
		List<Number> sourceList;
		ArrayList<Number> array = new ArrayList<Number>();
		
    	if (series == 1) {
    		sourceList = Arrays.asList(3, 2, 1, 3, 4);
    		array = new ArrayList<Number>(sourceList);
    	}
    	else if (series == 2) {
    		sourceList = Arrays.asList(2, 3, 5, 7, 6);
    		array = new ArrayList<Number>(sourceList);
    	}
    	else if (series == 3) {
    		sourceList = Arrays.asList(4, 3, 3, 9, 0);
    		array = new ArrayList<Number>(sourceList);
    	}
    	else if (series == 4) {
    		sourceList = Arrays.asList(3, 2.67, 3, 6.33, 3.33);
    		array = new ArrayList<Number>(sourceList);
    	}
    	else if (series == 5) {
    		sourceList = Arrays.asList(100, 80);
    		array = new ArrayList<Number>(sourceList);
    	}

    	return array;
    }
	
	public ArrayList<Data> getPieData(int series) {
		ArrayList<Data> array = new ArrayList<Data>();

		array.add(new Data().name("Jane").y(13).color(new Color().setColorValue("Highcharts.getOptions().colors[0]")));
		array.add(new Data().name("John").y(23).color(new Color().setColorValue("Highcharts.getOptions().colors[1]")));
		array.add(new Data().name("Joe").y(19).color(new Color().setColorValue("Highcharts.getOptions().colors[2]")));

    	return array;
    }
}
