package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.text.DecimalFormat;
import java.util.ArrayList;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.Series;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.responsive.Rules;
import com.hyjavacharts.model.highcharts.series.SeriesPie;
import com.hyjavacharts.model.highcharts.series.seriespie.Data;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class DonutChart extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		//highChart.setTheme(Theme.DARK_UNICA);
	    
		chartOptions.chart().type(ChartType.PIE);
		
		chartOptions.title().text("Browser market shares. January, 2015 to May, 2015");
		chartOptions.subtitle().text("Source: <a href=\"http://netmarketshare.com/\">netmarketshare.com</a>");
	
		chartOptions.xAxis().add(new XAxis().type(AxisType.CATEGORY));
	
		YAxis yAxi = new YAxis();
		yAxi.title().text("Total percent market share");
		chartOptions.yAxis().add(yAxi);
		
		chartOptions.plotOptions().pie().shadowAsBoolean(false);
		chartOptions.plotOptions().pie().centerAsArrayString().add("50%");
		chartOptions.plotOptions().pie().centerAsArrayString().add("50%");
	
		chartOptions.tooltip().valueSuffix("%");
		
		SeriesPie seriesPie = new SeriesPie();
		seriesPie.name("Browsers")
			.sizeAsString("60%")
			.dataLabels()
				.color(new Color("#ffffff"))
				.distance(-30)
				.formatter().setFunctionBody("return this.y > 5 ? this.point.name : null;");
		seriesPie.dataAsArrayObject(getSeriesData(1));
		chartOptions.series().add(seriesPie);
		
		seriesPie = new SeriesPie();
		seriesPie.name("Versions")
			.sizeAsString("80%")
			.innerSizeAsString("60%")
			.id("versions")
			.dataLabels().formatter().setFunctionBody("return this.y > 1 ? '<b>' + this.point.name + ':</b> ' + this.y + '%' : null;");
		seriesPie.dataAsArrayObject(getSeriesDrilldownData(1));
		chartOptions.series().add(seriesPie);

		ArrayList<Rules> rules = new ArrayList<Rules>();
		
		Rules r = new Rules();
		r.condition().maxWidth(400);
		rules.add(r);
		
		ArrayList<Series> series = new ArrayList<Series>();
		SeriesPie sp = new SeriesPie();
		sp.id("versions").dataLabels().enabled(false);
		series.add(sp);
		
		r = new Rules();
		r.chartOptions().series(series);
		rules.add(r);
		
		chartOptions.responsive().rules(rules);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Data> getSeriesData(int series) {
		ArrayList<Data> data = new ArrayList<Data>();
		
		data.add(new Data().name("MSIE").y(56.33).drilldown("MSIE").color(new Color("#7cb5ec")));
		data.add(new Data().name("Firefox").y(10.38f).drilldown("Firefox").color(new Color("#434348")));
		data.add(new Data().name("Chrome").y(24.03f).drilldown("Chrome").color(new Color("#90ed7d")));
		data.add(new Data().name("Safari").y(4.77f).drilldown("Safari").color(new Color("#f7a35c")));
		data.add(new Data().name("Opera").y(0.91f).drilldown("Opera").color(new Color("#8085e9")));
		data.add(new Data().name("Proprietary or Undetectable").y(0.2f).drilldown(null).color(new Color("#f15c80")));

		return data;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Data> getSeriesDrilldownData(int series) {
		ArrayList<Data> data = new ArrayList<Data>();
		
			DecimalFormat df = new DecimalFormat("0.00000"); 
			double brightness;
		
			// MSIE
			brightness = 0.2 - ( 1.0 / 6.0) / 5.0;
			data.add(new Data().name("MSIE 6.0").y(1.06)
					.color(new Color().setColorValue("Highcharts.Color(\"#7cb5ec\").brighten(" + (df.format(brightness)) + ").get()")));
					//.color(new Color().setColorValue("Highcharts.Color(colors[0]).brighten(" + (df.format(brightness)) + ").get()")));

			brightness = 0.2 - ( 2.0 / 6.0) / 5.0;
			data.add(new Data().name("MSIE 7.0").y(0.5)
					.color(new Color().setColorValue("Highcharts.Color(\"#7cb5ec\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 3.0 / 6.0) / 5.0;
			data.add(new Data().name("MSIE 8.0").y(17.2)
					.color(new Color().setColorValue("Highcharts.Color(\"#7cb5ec\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 4.0 / 6.0) / 5.0;
			data.add(new Data().name("MSIE 9.0").y(8.11)
					.color(new Color().setColorValue("Highcharts.Color(\"#7cb5ec\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 5.0 / 6.0) / 5.0;
			data.add(new Data().name("MSIE 10.0").y(5.33)
					.color(new Color().setColorValue("Highcharts.Color(\"#7cb5ec\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 6.0 / 6.0) / 5.0;
			data.add(new Data().name("MSIE 11.0").y(24.13)
					.color(new Color().setColorValue("Highcharts.Color(\"#7cb5ec\").brighten(" + (df.format(brightness)) + ").get()")));
			
			// Firefox
			brightness = 0.2 - ( 1.0 / 8.0) / 5.0;
			data.add(new Data().name("Firefox v31").y(0.33)
					.color(new Color().setColorValue("Highcharts.Color(\"#434348\").brighten(" + (df.format(brightness)) + ").get()")));
						
			brightness = 0.2 - ( 2.0 / 8.0) / 5.0;
			data.add(new Data().name("Firefox v32").y(0.15)
					.color(new Color().setColorValue("Highcharts.Color(\"#434348\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 3.0 / 8.0) / 5.0;
			data.add(new Data().name("Firefox v33").y(0.22)
					.color(new Color().setColorValue("Highcharts.Color(\"#434348\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 4.0 / 8.0) / 5.0;
			data.add(new Data().name("Firefox v34").y(1.27)
					.color(new Color().setColorValue("Highcharts.Color(\"#434348\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 5.0 / 8.0) / 5.0;
			data.add(new Data().name("Firefox v35").y(2.76)
					.color(new Color().setColorValue("Highcharts.Color(\"#434348\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 6.0 / 8.0) / 5.0;
			data.add(new Data().name("Firefox v36").y(2.32)
					.color(new Color().setColorValue("Highcharts.Color(\"#434348\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 7.0 / 8.0) / 5.0;
			data.add(new Data().name("Firefox v37").y(2.31)
					.color(new Color().setColorValue("Highcharts.Color(\"#434348\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 8.0 / 8.0) / 5.0;
			data.add(new Data().name("Firefox v38").y(1.02)
					.color(new Color().setColorValue("Highcharts.Color(\"#434348\").brighten(" + (df.format(brightness)) + ").get()")));
			
			// Chrome
			brightness = 0.2 - ( 1.0 / 14.0) / 5.0;
			data.add(new Data().name("Chrome v30.0").y(0.14)
					.color(new Color().setColorValue("Highcharts.Color(\"#90ed7d\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 2.0 / 14.0) / 5.0;
			data.add(new Data().name("Chrome v31.0").y(1.24)
					.color(new Color().setColorValue("Highcharts.Color(\"#90ed7d\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 3.0 / 14.0) / 5.0;
			data.add(new Data().name("Chrome v32.0").y(0.55)
					.color(new Color().setColorValue("Highcharts.Color(\"#90ed7d\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 4.0 / 14.0) / 5.0;
			data.add(new Data().name("Chrome v33.0").y(0.19)
					.color(new Color().setColorValue("Highcharts.Color(\"#90ed7d\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 5.0 / 14.0) / 5.0;
			data.add(new Data().name("Chrome v34.0").y(0.14)
					.color(new Color().setColorValue("Highcharts.Color(\"#90ed7d\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 6.0 / 14.0) / 5.0;
			data.add(new Data().name("Chrome v35.0").y(0.85)
					.color(new Color().setColorValue("Highcharts.Color(\"#90ed7d\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 7.0 / 14.0) / 5.0;
			data.add(new Data().name("Chrome v36.0").y(2.53)
					.color(new Color().setColorValue("Highcharts.Color(\"#90ed7d\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 8.0 / 14.0) / 5.0;
			data.add(new Data().name("Chrome v37.0").y(0.38)
					.color(new Color().setColorValue("Highcharts.Color(\"#90ed7d\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 9.0 / 14.0) / 5.0;
			data.add(new Data().name("Chrome v38.0").y(0.6)
					.color(new Color().setColorValue("Highcharts.Color(\"#90ed7d\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 10.0 / 14.0) / 5.0;
			data.add(new Data().name("Chrome v39.0").y(2.96)
					.color(new Color().setColorValue("Highcharts.Color(\"#90ed7d\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 11.0 / 14.0) / 5.0;
			data.add(new Data().name("Chrome v40.0").y(5)
					.color(new Color().setColorValue("Highcharts.Color(\"#90ed7d\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 12.0 / 14.0) / 5.0;
			data.add(new Data().name("Chrome v41.0").y(4.32)
					.color(new Color().setColorValue("Highcharts.Color(\"#90ed7d\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 13.0 / 14.0) / 5.0;
			data.add(new Data().name("Chrome v42.0").y(3.68)
					.color(new Color().setColorValue("Highcharts.Color(\"#90ed7d\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 14.0 / 14.0) / 5.0;
			data.add(new Data().name("Chrome v43.0").y(1.45)
					.color(new Color().setColorValue("Highcharts.Color(\"#90ed7d\").brighten(" + (df.format(brightness)) + ").get()")));
		
			// Safari
			brightness = 0.2 - ( 1.0 / 7.0) / 5.0;
			data.add(new Data().name("Safari v5.0").y(0.3)
					.color(new Color().setColorValue("Highcharts.Color(\"#f7a35c\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 2.0 / 7.0) / 5.0;
			data.add(new Data().name("Safari v5.1").y(0.42)
					.color(new Color().setColorValue("Highcharts.Color(\"#f7a35c\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 3.0 / 7.0) / 5.0;
			data.add(new Data().name("Safari v6.1").y(0.29)
					.color(new Color().setColorValue("Highcharts.Color(\"#f7a35c\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 4.0 / 7.0) / 5.0;
			data.add(new Data().name("Safari v6.2").y(0.17)
					.color(new Color().setColorValue("Highcharts.Color(\"#f7a35c\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 5.0 / 7.0) / 5.0;
			data.add(new Data().name("Safari v7.0").y(0.26)
					.color(new Color().setColorValue("Highcharts.Color(\"#f7a35c\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 6.0 / 7.0) / 5.0;
			data.add(new Data().name("Safari v7.1").y(0.77)
					.color(new Color().setColorValue("Highcharts.Color(\"#f7a35c\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 7.0 / 7.0) / 5.0;
			data.add(new Data().name("Safari v8.0").y(2.56)
					.color(new Color().setColorValue("Highcharts.Color(\"#f7a35c\").brighten(" + (df.format(brightness)) + ").get()")));

			// Opera
			brightness = 0.2 - ( 1.0 / 4.0) / 5.0;
			data.add(new Data().name("Opera v12.x").y(0.34)
					.color(new Color().setColorValue("Highcharts.Color(\"#8085e9\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 2.0 / 4.0) / 5.0;
			data.add(new Data().name("Opera v27").y(0.17)
					.color(new Color().setColorValue("Highcharts.Color(\"#8085e9\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 3.0 / 4.0) / 5.0;
			data.add(new Data().name("Opera v28").y(0.24)
					.color(new Color().setColorValue("Highcharts.Color(\"#8085e9\").brighten(" + (df.format(brightness)) + ").get()")));
			
			brightness = 0.2 - ( 4.0 / 4.0) / 5.0;
			data.add(new Data().name("Opera v29").y(0.16)
					.color(new Color().setColorValue("Highcharts.Color(\"#8085e9\").brighten(" + (df.format(brightness)) + ").get()")));
		
		return data;
	}
}
