package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.constants.ZoomType;
import com.hyjavacharts.model.highcharts.series.SeriesColumn;
import com.hyjavacharts.model.highcharts.series.SeriesErrorbar;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class ErrorBar extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		//highChart.setTheme(Theme.DARK_UNICA);
		
		chartOptions.chart().zoomType(ZoomType.XY);
		chartOptions.title().text("Temperature vs Rainfall");

		chartOptions.xAxisSingle().categories(new ArrayList<String>(Arrays.asList(
				"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec")));

		YAxis yAxi = new YAxis();
		yAxi.labels()
			.format("{value} °C")
			.style().setCssValue("{color: Highcharts.getOptions().colors[1]}");
			//.color(new Color().setJsonString("Highcharts.getOptions().colors[1]"));
		yAxi.title().text("Temperature")
			.style().setCssValue("{color: Highcharts.getOptions().colors[1]}");
			//.color(new Color().setJsonString("Highcharts.getOptions().colors[1]"));
		chartOptions.yAxis().add(yAxi);
		
		yAxi = new YAxis();
		yAxi.opposite(true)
			.labels()
			.format("{value} mm")
			.style().setCssValue("{color: Highcharts.getOptions().colors[0]}");
			//.color(new Color().setJsonString("Highcharts.getOptions().colors[0]"));
		yAxi.title()
			.text("Rainfall")
			.style().setCssValue("{color: Highcharts.getOptions().colors[0]}");
			//.color(new Color().setJsonString("Highcharts.getOptions().colors[0]"));
		chartOptions.yAxis().add(yAxi);
		
		chartOptions.tooltip().shared(true);
		
		SeriesColumn seriesColumn = new SeriesColumn();
		seriesColumn.type(SeriesType.COLUMN)
			.name("Rainfall")
			.yAxisAsNumber(1)
			.tooltip().pointFormat("<span style=\"font-weight: bold; color: {series.color}\">{series.name}</span>: <b>{point.y:.1f} mm</b> ");
		seriesColumn.dataAsArrayNumber(getSeriesData(1));
		chartOptions.series().add(seriesColumn);
		
		SeriesErrorbar seriesErrorbar = new SeriesErrorbar();
		seriesErrorbar.type(SeriesType.ERRORBAR)
			.name("Rainfall error")
			.yAxisAsNumber(1)
			.tooltip().pointFormat("(error range: {point.low}-{point.high} mm)<br/>");
		seriesErrorbar.dataAsArrayJavaObject(getSeriesErrorData(1));
		chartOptions.series().add(seriesErrorbar);
		
		SeriesSpline seriesSpline = new SeriesSpline();
		seriesSpline.type(SeriesType.SPLINE)
			.name("Temperature")
			.tooltip().pointFormat("<span style=\"font-weight: bold; color: {series.color}\">{series.name}</span>: <b>{point.y:.1f}°C</b> ");
		seriesSpline.dataAsArrayNumber(getSeriesData(2));
		chartOptions.series().add(seriesSpline);

		seriesErrorbar = new SeriesErrorbar();
		seriesErrorbar.type(SeriesType.ERRORBAR)
			.name("Temperature error")
			.tooltip().pointFormat("(error range: {point.low}-{point.high}°C)<br/>");
		seriesErrorbar.dataAsArrayJavaObject(getSeriesErrorData(2));
		chartOptions.series().add(seriesErrorbar);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Number> getSeriesData(int series) {
		ArrayList<Number> array = new ArrayList<Number>();
		
    	if (series == 1) {
    		array = new ArrayList<Number>(Arrays.asList(49.9, 71.5, 106.4, 129.2, 144.0, 176.0, 135.6, 148.5, 216.4, 194.1, 95.6, 54.4));
    	}
    	else if (series == 2) {
    		array = new ArrayList<Number>(Arrays.asList(7.0, 6.9, 9.5, 14.5, 18.2, 21.5, 25.2, 26.5, 23.3, 18.3, 13.9, 9.6));
    	}

    	return array;
    }
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Object> getSeriesErrorData(int series) {
		ArrayList<Object> array = new ArrayList<Object>();
		
    	if (series == 1) {
    		array.add(new ArrayList<Number>(Arrays.asList(48, 51)));
    		array.add(new ArrayList<Number>(Arrays.asList(68, 73)));
    		array.add(new ArrayList<Number>(Arrays.asList(92, 110)));
    		array.add(new ArrayList<Number>(Arrays.asList(128, 136)));
    		array.add(new ArrayList<Number>(Arrays.asList(140, 150)));
    		array.add(new ArrayList<Number>(Arrays.asList(171, 179)));
    		array.add(new ArrayList<Number>(Arrays.asList(135, 143)));
    		array.add(new ArrayList<Number>(Arrays.asList(142, 149)));
    		array.add(new ArrayList<Number>(Arrays.asList(204, 220)));
    		array.add(new ArrayList<Number>(Arrays.asList(189, 199)));
    		array.add(new ArrayList<Number>(Arrays.asList(95, 110)));
    		array.add(new ArrayList<Number>(Arrays.asList(52, 56)));
     	}
    	else if (series == 2) {
    		array.add(new ArrayList<Number>(Arrays.asList(6, 8)));
    		array.add(new ArrayList<Number>(Arrays.asList(5.9, 7.6)));
    		array.add(new ArrayList<Number>(Arrays.asList(9.4, 10.4)));
    		array.add(new ArrayList<Number>(Arrays.asList(14.1, 15.9)));
    		array.add(new ArrayList<Number>(Arrays.asList(18.0, 20.1)));
    		array.add(new ArrayList<Number>(Arrays.asList(21.0, 24.0)));
    		array.add(new ArrayList<Number>(Arrays.asList(23.2, 25.3)));
    		array.add(new ArrayList<Number>(Arrays.asList(26.1, 27.8)));
    		array.add(new ArrayList<Number>(Arrays.asList(23.2, 23.9)));
    		array.add(new ArrayList<Number>(Arrays.asList(18.0, 21.1)));
    		array.add(new ArrayList<Number>(Arrays.asList(12.9, 14.0)));
    		array.add(new ArrayList<Number>(Arrays.asList(7.6, 10.0)));
    	}

    	return array;
    }
}
