package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.Layout;
import com.hyjavacharts.model.highcharts.constants.VerticalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesHeatmap;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class HeatMap extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart().type(ChartType.HEATMAP)
			.marginTop(40)
			.marginBottom(80)
			.plotBorderWidth(1);
		chartOptions.title().text("Sales per employee per weekday");
		
		XAxis xAxis = new XAxis();
		xAxis.categories(new ArrayList<String>(Arrays.asList("Alexander", "Marie", "Maximilian", "Sophia", "Lukas", "Maria", "Leon", "Anna", "Tim", "Laura")));
		chartOptions.xAxis().add(xAxis);

		YAxis yAxis = new YAxis();
		yAxis.categories(new ArrayList<String>(Arrays.asList("Monday", "Tuesday", "Wednesday", "Thursday", "Friday")));
		yAxis.title().text(null);
		chartOptions.yAxis().add(yAxis);

		chartOptions.colorAxis()
			.min(0)
			.minColor(new Color("#FFFFFF"))
			.maxColor().setColorValue("Highcharts.getOptions().colors[0]");
		
		chartOptions.legend()
			.align(HorizontalAlign.RIGHT)
			.layout(Layout.VERTICAL)
			.margin(0)
			.verticalAlign(VerticalAlign.TOP)
			.y(25)
			.symbolHeight(328);
		
		chartOptions.tooltip()
			.formatter()
				.setFunctionBody("return '<b>' + this.series.xAxis.categories[this.point.x] + '</b> sold <br><b>' + this.point.value + '</b> items on <br><b>' + this.series.yAxis.categories[this.point.y] + '</b>';");
		
		SeriesHeatmap seriesHeatmap = new SeriesHeatmap();
		seriesHeatmap
			.name("Sales per employee")
			.borderWidth(1)
			.dataLabels()
				.enabled(true)
				.color(new Color("#000000"));
		seriesHeatmap.dataAsArrayJavaObject(getSeriesData(1));
		chartOptions.series().add(seriesHeatmap);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	public List<Object> getSeriesData(int series) {
		List<Object> array = new ArrayList<Object>();
		
		array.add(new ArrayList<Number>(Arrays.asList(0, 0, 10)));
		array.add(new ArrayList<Number>(Arrays.asList(0, 1, 19))); 
		array.add(new ArrayList<Number>(Arrays.asList(0, 2, 8))); 
		array.add(new ArrayList<Number>(Arrays.asList(0, 3, 24))); 
		array.add(new ArrayList<Number>(Arrays.asList(0, 4, 67))); 
		array.add(new ArrayList<Number>(Arrays.asList(1, 0, 92))); 
		array.add(new ArrayList<Number>(Arrays.asList(1, 1, 58))); 
		array.add(new ArrayList<Number>(Arrays.asList(1, 2, 78))); 
		array.add(new ArrayList<Number>(Arrays.asList(1, 3, 117))); 
		array.add(new ArrayList<Number>(Arrays.asList(1, 4, 48))); 
		array.add(new ArrayList<Number>(Arrays.asList(2, 0, 35))); 
		array.add(new ArrayList<Number>(Arrays.asList(2, 1, 15))); 
		array.add(new ArrayList<Number>(Arrays.asList(2, 2, 123))); 
		array.add(new ArrayList<Number>(Arrays.asList(2, 3, 64))); 
		array.add(new ArrayList<Number>(Arrays.asList(2, 4, 52))); 
		array.add(new ArrayList<Number>(Arrays.asList(3, 0, 72))); 
		array.add(new ArrayList<Number>(Arrays.asList(3, 1, 132))); 
		array.add(new ArrayList<Number>(Arrays.asList(3, 2, 114)));
		array.add(new ArrayList<Number>(Arrays.asList(3, 3, 19)));
		array.add(new ArrayList<Number>(Arrays.asList(3, 4, 16)));
		array.add(new ArrayList<Number>(Arrays.asList(4, 0, 38)));
		array.add(new ArrayList<Number>(Arrays.asList(4, 1, 5)));
		array.add(new ArrayList<Number>(Arrays.asList(4, 2, 8)));
		array.add(new ArrayList<Number>(Arrays.asList(4, 3, 117)));
		array.add(new ArrayList<Number>(Arrays.asList(4, 4, 115)));
		array.add(new ArrayList<Number>(Arrays.asList(5, 0, 88)));
		array.add(new ArrayList<Number>(Arrays.asList(5, 1, 32)));
		array.add(new ArrayList<Number>(Arrays.asList(5, 2, 12)));
		array.add(new ArrayList<Number>(Arrays.asList(5, 3, 6)));
		array.add(new ArrayList<Number>(Arrays.asList(5, 4, 120)));
		array.add(new ArrayList<Number>(Arrays.asList(6, 0, 13)));
		array.add(new ArrayList<Number>(Arrays.asList(6, 1, 44)));
		array.add(new ArrayList<Number>(Arrays.asList(6, 2, 88)));
		array.add(new ArrayList<Number>(Arrays.asList(6, 3, 98)));
		array.add(new ArrayList<Number>(Arrays.asList(6, 4, 96)));
		array.add(new ArrayList<Number>(Arrays.asList(7, 0, 31)));
		array.add(new ArrayList<Number>(Arrays.asList(7, 1, 1)));
		array.add(new ArrayList<Number>(Arrays.asList(7, 2, 82)));
		array.add(new ArrayList<Number>(Arrays.asList(7, 3, 32)));
		array.add(new ArrayList<Number>(Arrays.asList(7, 4, 30)));
		array.add(new ArrayList<Number>(Arrays.asList(8, 0, 85)));
		array.add(new ArrayList<Number>(Arrays.asList(8, 1, 97)));
		array.add(new ArrayList<Number>(Arrays.asList(8, 2, 123)));
		array.add(new ArrayList<Number>(Arrays.asList(8, 3, 64)));
		array.add(new ArrayList<Number>(Arrays.asList(8, 4, 84)));
		array.add(new ArrayList<Number>(Arrays.asList(9, 0, 47)));
		array.add(new ArrayList<Number>(Arrays.asList(9, 1, 114)));
		array.add(new ArrayList<Number>(Arrays.asList(9, 2, 31)));
		array.add(new ArrayList<Number>(Arrays.asList(9, 3, 48)));
		array.add(new ArrayList<Number>(Arrays.asList(9, 4, 91)));

    	return array;
    }
}
