package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.Stacking;
import com.hyjavacharts.model.highcharts.constants.TickmarkPlacement;
import com.hyjavacharts.model.highcharts.series.SeriesArea;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class PercentageArea extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart()
			.type(ChartType.AREA);
		chartOptions.title()
			.text("Historic and Estimated Worldwide Population Growth by Region");
		
		chartOptions.subtitle()
			.text("Source: Wikipedia.org");
		
		XAxis xAxi = new XAxis();
		xAxi.categories(new ArrayList<String>(Arrays.asList("1750", "1800", "1850", "1900", "1950", "1999", "2050")))
			.tickmarkPlacement(TickmarkPlacement.ON)
			.title().text(null);
		chartOptions.xAxis().add(xAxi);

		YAxis yAxi = new YAxis();
		yAxi.title().text("Percent");
		chartOptions.yAxis().add(yAxi);

		chartOptions.tooltip()
			.pointFormat("<span style=\"color:{series.color}\">{series.name}</span>: <b>{point.percentage:.1f}%</b> ({point.y:,.0f} millions)<br/>")
			.split(true);

		chartOptions.plotOptions().area()
			.stacking(Stacking.PERCENT)
			.lineColor(new Color("#ffffff"))
			.lineWidth(1)
			.marker()
				.lineWidth(1)
				.lineColor(new Color("#ffffff"));
		
		SeriesArea seriesArea = new SeriesArea();
		seriesArea.name("Asia");
		seriesArea.dataAsArrayNumber(getSeriesData(1));
		chartOptions.series().add(seriesArea);
		
		seriesArea = new SeriesArea();
		seriesArea.name("Africa");
		seriesArea.dataAsArrayNumber(getSeriesData(2));
		chartOptions.series().add(seriesArea);
		
		seriesArea = new SeriesArea();
		seriesArea.name("Europe");
		seriesArea.dataAsArrayNumber(getSeriesData(3));
		chartOptions.series().add(seriesArea);
		
		seriesArea = new SeriesArea();
		seriesArea.name("America");
		seriesArea.dataAsArrayNumber(getSeriesData(4));
		chartOptions.series().add(seriesArea);
		
		seriesArea = new SeriesArea();
		seriesArea.name("Oceania");
		seriesArea.dataAsArrayNumber(getSeriesData(5));
		chartOptions.series().add(seriesArea);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Number> getSeriesData(int series) {
		ArrayList<Number> array = new ArrayList<Number>();
		
    	if (series == 1) {
    		array = new ArrayList<Number>(Arrays.asList(502, 635, 809, 947, 1402, 3634, 5268));
    	}
    	else if (series == 2) {
    		array = new ArrayList<Number>(Arrays.asList(106, 107, 111, 133, 221, 767, 1766));
    	}
    	else if (series == 3) {
    		array = new ArrayList<Number>(Arrays.asList(163, 203, 276, 408, 547, 729, 628));
    	}
    	else if (series == 4) {
    		array = new ArrayList<Number>(Arrays.asList(18, 31, 54, 156, 339, 818, 1201));
    	}
    	else if (series == 5) {
    		array = new ArrayList<Number>(Arrays.asList(2, 2, 2, 6, 13, 30, 46));
    	}

    	return array;
    }
}
