package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.GenericOption;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.series.SeriesPie;
import com.hyjavacharts.model.highcharts.series.seriespie.Data;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class PieWithDrilldown extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
				
		chartOptions.chart()
			.type(ChartType.PIE);
		
		chartOptions.title().text("Browser market shares January, 2015 to May, 2015");
		chartOptions.subtitle().text("Click the slices to view versions. Source: netmarketshare.com.");
		
		chartOptions.plotOptions()
			.pie()
				.dataLabels()
					.enabled(true)
					.format("{point.name}: {point.y:.1f}%");
		
		chartOptions.tooltip()
			.headerFormat("<span style=\"font-size:11px\">{series.name}</span><br>")
			.pointFormat("<span style=\"color:{point.color}\">{point.name}</span>: <b>{point.y:.2f}%</b> of total<br/>");
		
		// Brands series
		SeriesPie seriesPie = new SeriesPie();
		seriesPie.name("Brands")
			//.get_genericOption1().setPropertyName("colorByPoint").setPropertyValue("true");	// not in hc api .colorByPoint(true);
			.get_genericOption().add(new GenericOption().setPropertyName("colorByPoint").setPropertyValue("true"));	// not in hc api .colorByPoint(true);
		seriesPie.dataAsArrayObject(getSeriesData(1));
		chartOptions.series().add(seriesPie);
		
		// Drilldowns
		SeriesPie seriesDrilldownColumn = new SeriesPie();
		seriesDrilldownColumn.name("Microsoft Internet Explorer").id("Microsoft Internet Explorer");
		seriesDrilldownColumn.dataAsArrayObject(getSeriesDrilldownData(1));
		chartOptions.drilldown().series().add(seriesDrilldownColumn);
		
		seriesDrilldownColumn = new SeriesPie();
		seriesDrilldownColumn.name("Chrome").id("Chrome");
		seriesDrilldownColumn.dataAsArrayObject(getSeriesDrilldownData(2));
		chartOptions.drilldown().series().add(seriesDrilldownColumn);
		
		seriesDrilldownColumn = new SeriesPie();
		seriesDrilldownColumn.name("Firefox").id("Firefox");
		seriesDrilldownColumn.dataAsArrayObject(getSeriesDrilldownData(3));
		chartOptions.drilldown().series().add(seriesDrilldownColumn);
		
		seriesDrilldownColumn = new SeriesPie();
		seriesDrilldownColumn.name("Safari").id("Safari");
		seriesDrilldownColumn.dataAsArrayObject(getSeriesDrilldownData(4));
		chartOptions.drilldown().series().add(seriesDrilldownColumn);
		
		seriesDrilldownColumn = new SeriesPie();
		seriesDrilldownColumn.name("Opera").id("Opera");
		seriesDrilldownColumn.dataAsArrayObject(getSeriesDrilldownData(5));
		chartOptions.drilldown().series().add(seriesDrilldownColumn);
		
		seriesDrilldownColumn = new SeriesPie();
		seriesDrilldownColumn.name("Proprietary or Undetectable").id("Proprietary or Undetectable");
		seriesDrilldownColumn.dataAsArrayObject(getSeriesDrilldownData(6));
		chartOptions.drilldown().series().add(seriesDrilldownColumn);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	public ArrayList<Data> getSeriesData(int series) {
		ArrayList<Data> data = new ArrayList<Data>();
		
		data.add(new Data().name("Microsoft Internet Explorer").y(56.33).drilldown("Microsoft Internet Explorer"));
		data.add(new Data().name("Chrome").y(24.03f).drilldown("Chrome"));
		data.add(new Data().name("Firefox").y(10.38f).drilldown("Firefox"));
		data.add(new Data().name("Safari").y(4.77f).drilldown("Safari"));
		data.add(new Data().name("Opera").y(0.91f).drilldown("Opera"));
		data.add(new Data().name("Proprietary or Undetectable").y(0.2f).drilldown(null));
		
		return data;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	public ArrayList<Data> getSeriesDrilldownData(int series) {
		ArrayList<Data> data = new ArrayList<Data>();
		
		if (series == 1) {
			data.add(new Data().name("v11.0").y(24.13));
			data.add(new Data().name("v8.0").y(17.2));
			data.add(new Data().name("v9.0").y(8.11));
			data.add(new Data().name("v10.0").y(5.33));
			data.add(new Data().name("v6.0").y(1.06));
			data.add(new Data().name("v7.0").y(0.5));
		}
		else if (series == 2) {
			data.add(new Data().name("v40.0").y(5));
			data.add(new Data().name("v41.0").y(4.32));
			data.add(new Data().name("v42.0").y(3.68));
			data.add(new Data().name("v39.0").y(2.96));
			data.add(new Data().name("v36.0").y(2.53));
			data.add(new Data().name("v43.0").y(1.45));
			data.add(new Data().name("v31.0").y(1.24));
			data.add(new Data().name("v35.0").y(0.85));
			data.add(new Data().name("v38.0").y(0.6));
			data.add(new Data().name("v32.0").y(0.55));
			data.add(new Data().name("v37.0").y(0.38));
			data.add(new Data().name("v33.0").y(0.19));
			data.add(new Data().name("v34.0").y(0.14));
			data.add(new Data().name("v30.0").y(0.14));
		}
		else if (series == 3) {
			data.add(new Data().name("v35").y(2.76));
			data.add(new Data().name("v36").y(2.32));
			data.add(new Data().name("v37").y(2.31));
			data.add(new Data().name("v34").y(1.27));
			data.add(new Data().name("v38").y(1.02));
			data.add(new Data().name("v31").y(0.33));
			data.add(new Data().name("v33").y(0.22));
			data.add(new Data().name("v32").y(0.15));
		}
		else if (series == 4) {
			data.add(new Data().name("v8.0").y(2.56));
			data.add(new Data().name("v7.1").y(0.77));
			data.add(new Data().name("v5.1").y(0.42));
			data.add(new Data().name("v5.0").y(0.3));
			data.add(new Data().name("v6.1").y(0.29));
			data.add(new Data().name("v7.0").y(0.26));
			data.add(new Data().name("v6.2").y(0.17));
		}
		else if (series == 5) {
			data.add(new Data().name("v12.x").y(0.34));
			data.add(new Data().name("v28").y(0.24));
			data.add(new Data().name("v27").y(0.17));
			data.add(new Data().name("v29").y(0.16));
		}
		
		return data;
	}
}
