package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.GridLineInterpolation;
import com.hyjavacharts.model.highcharts.constants.HorizontalAlign;
import com.hyjavacharts.model.highcharts.constants.Layout;
import com.hyjavacharts.model.highcharts.constants.PointPlacement;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.constants.TickmarkPlacement;
import com.hyjavacharts.model.highcharts.constants.VerticalAlign;
import com.hyjavacharts.model.highcharts.series.SeriesLine;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class SpiderWeb extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.chart().type(ChartType.LINE).polar(true);
		chartOptions.title().text("Budget vs spending").x(-80);
		
		chartOptions.paneSingle().sizeAsString("80%");
		
		chartOptions.xAxisSingle()
			.categories(new ArrayList<String>(Arrays.asList("Sales", "Marketing", "Development", "Customer Support", "Information Technology", "Administration")))
			.setTickmarkPlacement(TickmarkPlacement.ON)
			.lineWidth(0);

		chartOptions.yAxisSingle()
			.gridLineInterpolation(GridLineInterpolation.POLYGON)
			.lineWidth(0)
			.min(0);
		
		chartOptions.tooltip()
			.shared(true)
			.pointFormat("<span style=\"color:{series.color}\">{series.name}: <b>${point.y:,.0f}</b><br/>");

		chartOptions.legend()
			.align(HorizontalAlign.RIGHT)
			.verticalAlign(VerticalAlign.TOP)
			.y(70)
			.layout(Layout.VERTICAL);
		
		SeriesLine seriesLine = new SeriesLine();
		seriesLine.type(SeriesType.LINE)
			.name("Allocated Budget")
			.pointPlacementAsEnum(PointPlacement.ON);
		seriesLine.dataAsArrayNumber(new ArrayList<Number>(Arrays.asList(43000, 19000, 60000, 35000, 17000, 10000)));
		chartOptions.series().add(seriesLine);
		
		seriesLine = new SeriesLine();
		seriesLine.type(SeriesType.LINE)
			.name("Actual Spending")
			.pointPlacementAsEnum(PointPlacement.ON);
		seriesLine.dataAsArrayNumber(new ArrayList<Number>(Arrays.asList(50000, 39000, 42000, 31000, 26000, 14000)));
		chartOptions.series().add(seriesLine);
		
		return highChart;
	}

}
