package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.Symbol;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.hyjavacharts.model.highcharts.series.seriesspline.Data;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class SplineWithSymbols extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();

		chartOptions.chart().type(ChartType.SPLINE);
		chartOptions.title().text("Monthly Average Temperature");
		chartOptions.subtitle().text("Source: WorldClimate.com");

		XAxis xAxi = new XAxis();
		xAxi.crosshairAsBoolean(true).categories(new ArrayList<String>(Arrays.asList("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec")));
		chartOptions.xAxis().add(xAxi);

		YAxis yAxi = new YAxis();
		yAxi.title().text("Temperature");
		yAxi.labels().formatter().setFunctionBody("return this.value + '°';");
		chartOptions.yAxis().add(yAxi);

		chartOptions.tooltip().shared(true);
		chartOptions.plotOptions().spline().marker().radius(4).lineColor(new Color("#666666")).lineWidth(1);
		
		SeriesSpline seriesSpline = new SeriesSpline();
		seriesSpline.name("Tokyo").marker().symbolAsEnum(Symbol.SQUARE);
		seriesSpline.dataAsArrayObject(getSeriesData(1));
		chartOptions.series().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.name("London").marker().symbolAsEnum(Symbol.DIAMOND);
		seriesSpline.dataAsArrayObject(getSeriesData(2));
		chartOptions.series().add(seriesSpline);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	public ArrayList<Data> getSeriesData(int series) {
		ArrayList<Data> array = new ArrayList<Data>();
		
		if (series == 1) {
			Data d = new Data();
			d.y(26.5);
			d.marker().symbolAsString("url(https://www.highcharts.com/samples/graphics/sun.png)");
			
			array.add(new Data().y(7.0));
			array.add(new Data().y(6.9));
			array.add(new Data().y(9.5));
			array.add(new Data().y(14.5));
			array.add(new Data().y(18.2));
			array.add(new Data().y(21.5));
			array.add(new Data().y(25.2));
			array.add(d);
			array.add(new Data().y(23.3));
			array.add(new Data().y(18.3));
			array.add(new Data().y(13.9));
			array.add(new Data().y(9.6));
		}
		else {
			Data d = new Data();
			d.y(3.9);
			d.marker().symbolAsString("url(https://www.highcharts.com/samples/graphics/snow.png)");
			
			array.add(d);
			array.add(new Data().y(4.2));
			array.add(new Data().y(5.7));
			array.add(new Data().y(8.5));
			array.add(new Data().y(11.9));
			array.add(new Data().y(15.2));
			array.add(new Data().y(17.0));
			array.add(new Data().y(16.6));
			array.add(new Data().y(14.2));
			array.add(new Data().y(10.3));
			array.add(new Data().y(6.6));
			array.add(new Data().y(4.8));
		}
		
    	return array;
    }
}
