package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.GenericOption;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.series.SeriesScatter;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class ThreeDScatterChart extends DemoChartBase {
	
	/**
	 * 
	 */
	public ThreeDScatterChart() {
		setHeight("400px");
	}
	
	/**
	 * 
	 */
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();

		chartOptions.chart()
			.type(ChartType.SCATTER)
			.marginBottom(100)
			.options3d().enabled(true)
				.alpha(10)
				.beta(30)
				.depth(250)
				.viewDistance(5)
				.fitToPlot(false);
		chartOptions.chart().options3d().frame().bottom().size(1).color(new Color("rgba(0,0,0,0.02)"));
		chartOptions.chart().options3d().frame().back().size(1).color(new Color("rgba(0,0,0,0.04)"));
		chartOptions.chart().options3d().frame().side().size(1).color(new Color("rgba(0,0,0,0.06)"));
		
		chartOptions.title().text("Scatter Box");
		chartOptions.plotOptions().scatter().get_genericOption().add(new GenericOption("width", "10"));	// width/height/depth not in hc api
		chartOptions.plotOptions().scatter().get_genericOption().add(new GenericOption("height", "10"));
		chartOptions.plotOptions().scatter().get_genericOption().add(new GenericOption("depth", "10"));

		chartOptions.xAxisSingle()
			.min(0)
			.max(10)
			.title(null);
			
		chartOptions.yAxisSingle()
			.min(0)
			.max(10)
			.gridLineWidth(1);
		
		chartOptions.zAxis()
			.min(0)
			.max(10)
			.showFirstLabel(false);
		
		chartOptions.legend().enabled(false);
		
		SeriesScatter seriesScatter3d = new SeriesScatter();
		seriesScatter3d.name("Reading")
			//.get_genericOption1().setPropertyName("colorByPoint").setPropertyValue("true");	// not in hc api
			.get_genericOption().add(new GenericOption("colorByPoint", "true"));			// not in hc api
		seriesScatter3d.dataAsArrayJavaObject(getSeriesData(1));
		chartOptions.series().add(seriesScatter3d);
		
		// Create new colors list
		List<Color> newColors = new ArrayList<Color>();
		
		for (Color defaultColor : chartOptions.colors()) {
			String Radialize = "{ radialGradient: { cx: 0.4, cy: 0.3, r: 0.5 }, stops: [ [0, '" + defaultColor.getColor() + "'], [1, Highcharts.Color('" + defaultColor.getColor() + "').brighten(-0.2).get('rgb')] ] }";
			newColors.add(new Color().setColorValue(Radialize));
		}
		
		chartOptions.colors(newColors);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	public ArrayList<Object> getSeriesData(int series) {
		ArrayList<Object> array = new ArrayList<Object>();
		
		array.add(new ArrayList<Object>(Arrays.asList(1, 6, 5)));
		array.add(new ArrayList<Object>(Arrays.asList(8, 7, 9)));
		array.add(new ArrayList<Object>(Arrays.asList(1, 3, 4)));
		array.add(new ArrayList<Object>(Arrays.asList(4, 6, 8)));
		array.add(new ArrayList<Object>(Arrays.asList(5, 7, 7)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 9, 6)));
		array.add(new ArrayList<Object>(Arrays.asList(7, 0, 5)));
		array.add(new ArrayList<Object>(Arrays.asList(2, 3, 3)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 9, 8)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 6, 5)));
		array.add(new ArrayList<Object>(Arrays.asList(4, 9, 4)));
		array.add(new ArrayList<Object>(Arrays.asList(2, 3, 3)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 9, 9)));
		array.add(new ArrayList<Object>(Arrays.asList(0, 7, 0)));
		array.add(new ArrayList<Object>(Arrays.asList(7, 7, 9)));
		array.add(new ArrayList<Object>(Arrays.asList(7, 2, 9)));
		array.add(new ArrayList<Object>(Arrays.asList(0, 6, 2)));
		array.add(new ArrayList<Object>(Arrays.asList(4, 6, 7)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 7, 7)));
		array.add(new ArrayList<Object>(Arrays.asList(0, 1, 7)));
		array.add(new ArrayList<Object>(Arrays.asList(2, 8, 6)));
		array.add(new ArrayList<Object>(Arrays.asList(2, 3, 7)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 4, 8)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 5, 9)));
		array.add(new ArrayList<Object>(Arrays.asList(7, 9, 5)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 1, 7)));
		array.add(new ArrayList<Object>(Arrays.asList(4, 4, 2)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 6, 2)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 1, 6)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 8, 5)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 6, 7)));
		array.add(new ArrayList<Object>(Arrays.asList(4, 1, 1)));
		array.add(new ArrayList<Object>(Arrays.asList(7, 2, 7)));
		array.add(new ArrayList<Object>(Arrays.asList(7, 7, 0)));
		array.add(new ArrayList<Object>(Arrays.asList(8, 8, 9)));
		array.add(new ArrayList<Object>(Arrays.asList(9, 4, 1)));
		array.add(new ArrayList<Object>(Arrays.asList(8, 3, 4)));
		array.add(new ArrayList<Object>(Arrays.asList(9, 8, 9)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 5, 3)));
		array.add(new ArrayList<Object>(Arrays.asList(0, 2, 4)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 0, 2)));
		array.add(new ArrayList<Object>(Arrays.asList(2, 1, 3)));
		array.add(new ArrayList<Object>(Arrays.asList(5, 8, 9)));
		array.add(new ArrayList<Object>(Arrays.asList(2, 1, 1)));
		array.add(new ArrayList<Object>(Arrays.asList(9, 7, 6)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 0, 2)));
		array.add(new ArrayList<Object>(Arrays.asList(9, 9, 0)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 4, 8)));
		array.add(new ArrayList<Object>(Arrays.asList(2, 6, 1)));
		array.add(new ArrayList<Object>(Arrays.asList(8, 9, 2)));
		array.add(new ArrayList<Object>(Arrays.asList(7, 6, 5)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 3, 1)));
		array.add(new ArrayList<Object>(Arrays.asList(9, 3, 1)));
		array.add(new ArrayList<Object>(Arrays.asList(8, 9, 3)));
		array.add(new ArrayList<Object>(Arrays.asList(9, 1, 0)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 8, 7)));
		array.add(new ArrayList<Object>(Arrays.asList(8, 0, 0)));
		array.add(new ArrayList<Object>(Arrays.asList(4, 9, 7)));
		array.add(new ArrayList<Object>(Arrays.asList(8, 6, 2)));
		array.add(new ArrayList<Object>(Arrays.asList(4, 3, 0)));
		array.add(new ArrayList<Object>(Arrays.asList(2, 3, 5)));
		array.add(new ArrayList<Object>(Arrays.asList(9, 1, 4)));
		array.add(new ArrayList<Object>(Arrays.asList(1, 1, 4)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 0, 2)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 1, 6)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 8, 8)));
		array.add(new ArrayList<Object>(Arrays.asList(8, 8, 7)));
		array.add(new ArrayList<Object>(Arrays.asList(5, 5, 0)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 9, 6)));
		array.add(new ArrayList<Object>(Arrays.asList(5, 4, 3)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 8, 3)));
		array.add(new ArrayList<Object>(Arrays.asList(0, 1, 5)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 7, 3)));
		array.add(new ArrayList<Object>(Arrays.asList(8, 3, 2)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 8, 3)));
		array.add(new ArrayList<Object>(Arrays.asList(2, 1, 6)));
		array.add(new ArrayList<Object>(Arrays.asList(4, 6, 7)));
		array.add(new ArrayList<Object>(Arrays.asList(8, 9, 9)));
		array.add(new ArrayList<Object>(Arrays.asList(5, 4, 2)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 1, 3)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 9, 5)));
		array.add(new ArrayList<Object>(Arrays.asList(4, 8, 2)));
		array.add(new ArrayList<Object>(Arrays.asList(9, 7, 4)));
		array.add(new ArrayList<Object>(Arrays.asList(5, 4, 2)));
		array.add(new ArrayList<Object>(Arrays.asList(9, 6, 1)));
		array.add(new ArrayList<Object>(Arrays.asList(2, 7, 3)));
		array.add(new ArrayList<Object>(Arrays.asList(4, 5, 4)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 8, 1)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 4, 0)));
		array.add(new ArrayList<Object>(Arrays.asList(2, 2, 6)));
		array.add(new ArrayList<Object>(Arrays.asList(5, 1, 2)));
		array.add(new ArrayList<Object>(Arrays.asList(9, 9, 7)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 9, 9)));
		array.add(new ArrayList<Object>(Arrays.asList(8, 4, 3)));
		array.add(new ArrayList<Object>(Arrays.asList(4, 1, 7)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 2, 5)));
		array.add(new ArrayList<Object>(Arrays.asList(0, 4, 9)));
		array.add(new ArrayList<Object>(Arrays.asList(3, 5, 9)));
		array.add(new ArrayList<Object>(Arrays.asList(6, 9, 1)));
		array.add(new ArrayList<Object>(Arrays.asList(1, 9, 2)));

    	return array;
    }
}
