package com.webonlineapp.gwtdemo.server;

import java.util.ArrayList;
import java.util.Calendar;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.Function;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.GlobalOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.SeriesType;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.hyjavacharts.model.highcharts.series.seriesspline.Data;
import com.hyjavacharts.model.highcharts.yaxis.PlotLines;

public class DynamicSplineUpdating {
	
	private String loadFunction = 
			"var series = this.series[0];" + 
			"setInterval(function () {" + 
					"var x = (new Date()).getTime()," + 
					"y = Math.random();" + 
					"series.addPoint([x, y], true, true);" + 
				"}, 1000);";
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		GlobalOptions globalOptions = highChart.getGlobalOptions();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		globalOptions.global().useUTC(false);
		
		chartOptions.chart().type(ChartType.SPLINE).marginRight(10).events().load(new Function(loadFunction));
		chartOptions.title().text("Live random data");
		chartOptions.xAxis().add(new XAxis().type(AxisType.DATETIME).tickPixelInterval(150));
		
		YAxis yAxi = new YAxis();
		yAxi.title().text("Value");
		yAxi.plotLines().add(new PlotLines().value(0f).width(1).color(new Color("#808080")));
		chartOptions.yAxis().add(yAxi);
		
		chartOptions.tooltip().formatter()
			.setFunctionBody("return '<b>'+ this.series.name +'</b><br/>'+"
                    + "Highcharts.dateFormat('%Y-%m-%d %H:%M:%S', this.x) +'<br/>'+"
                    + "Highcharts.numberFormat(this.y, 2);");

		chartOptions.legend().enabled(true);
		chartOptions.exporting().enabled(true);
		
		SeriesSpline seriesSpline = new SeriesSpline();
		seriesSpline.type(SeriesType.SPLINE).name("Random data");
		seriesSpline.dataAsArrayObject(getSeriesData(1));
		chartOptions.series().add(seriesSpline);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	public ArrayList<Data> getSeriesData(int series) {
		Calendar cal = Calendar.getInstance();
		long now = cal.getTime().getTime();
		
		ArrayList<Data> data = new ArrayList<Data>();
		data.add(new Data().x(now-20000).y(Math.random()));
		data.add(new Data().x(now-19000).y(Math.random()));
		data.add(new Data().x(now-18000).y(Math.random()));
		data.add(new Data().x(now-17000).y(Math.random()));
		data.add(new Data().x(now-16000).y(Math.random()));
		data.add(new Data().x(now-15000).y(Math.random()));
		data.add(new Data().x(now-14000).y(Math.random()));
		data.add(new Data().x(now-13000).y(Math.random()));
		data.add(new Data().x(now-12000).y(Math.random()));
		data.add(new Data().x(now-11000).y(Math.random()));
		data.add(new Data().x(now-10000).y(Math.random()));
		data.add(new Data().x(now-9000).y(Math.random()));
		data.add(new Data().x(now-8000).y(Math.random()));
		data.add(new Data().x(now-7000).y(Math.random()));
		data.add(new Data().x(now-6000).y(Math.random()));
		data.add(new Data().x(now-5000).y(Math.random()));
		data.add(new Data().x(now-4000).y(Math.random()));
		data.add(new Data().x(now-3000).y(Math.random()));
		data.add(new Data().x(now-2000).y(Math.random()));
		data.add(new Data().x(now-1000).y(Math.random()));
		data.add(new Data().x(now).y(Math.random()));
		
		return data;
	}

}
	

